# Copyright 2014 by trgk.
# All rights reserved.
# This file is part of EUD python library (eudplib),
# and is released under "MIT License Agreement". Please see the LICENSE
# file that should have been included as part of this package.

import math
from collections.abc import Callable

from ... import utils as ut
from ...localize import _
from .. import allocator as ac
from .. import rawtrigger as rt
from .. import variable as ev
from ..eudfunc.eudf import EUDFunc, _EUDPredefineParam, _EUDPredefineReturn
from ..eudfunc.eudtypedfuncn import EUDTypedFuncN
from ..variable.evcommon import _ev


def f_mul(a, b, **kwargs):
    """Calculate a * b"""
    if ev.IsEUDVariable(a) and ev.IsEUDVariable(b):
        return _eud_mul(a, b, **kwargs)

    elif ev.IsEUDVariable(a):
        return _const_mul(b)(a, **kwargs)

    elif ev.IsEUDVariable(b):
        return _const_mul(a)(b, **kwargs)

    try:
        ret = kwargs["ret"][0]
    except KeyError:
        ret = ev.EUDVariable()
    ret << a * b
    return ret


def f_div(a, b, **kwargs):
    """Calculates quotient and remainder of a by b, with unsigned division.

    For signed division, uses `f_div_towards_zero`, `f_div_floor` and `f_div_euclid`.
    """
    if ut.isUnproxyInstance(a, int) and a < 0:
        raise ut.EPError(
            _("Can't use negative dividend for unsigned division: {}").format(a),
            _(
                "For signed division, use `f_div_towards_zero`, `f_div_floor` and `f_div_euclid`."
            ),  # noqa: E501
        )
    if ut.isUnproxyInstance(b, int) and b < 0:
        raise ut.EPError(
            _("Can't use negative divider for unsigned division: {}").format(a),
            _(
                "For signed division, use `f_div_towards_zero`, `f_div_floor` and `f_div_euclid`."
            ),  # noqa: E501
        )

    if ev.IsEUDVariable(b):
        return _eud_div(a, b, **kwargs)

    elif ev.IsEUDVariable(a):
        return _const_div(b)(a, **kwargs)

    if b:
        q, m = divmod(a, b)
    else:
        q, m = 0xFFFFFFFF, a
    try:
        vq, vm = kwargs["ret"]
    except KeyError:
        vq, vm = ev.EUDCreateVariables(2)
    ev.SeqCompute([(vq, rt.SetTo, q), (vm, rt.SetTo, m)])
    return vq, vm


def _quot(a, b, **kwargs):
    """Calculate (a//b)"""
    if ut.isUnproxyInstance(a, int) and a < 0:
        raise ut.EPError(
            _("Can't use negative dividend for unsigned division: {}").format(a),
            _(
                "For signed division, use `f_div_towards_zero`, `f_div_floor` and `f_div_euclid`."
            ),  # noqa: E501
        )
    if ut.isUnproxyInstance(b, int) and b < 0:
        raise ut.EPError(
            _("Can't use negative divider for unsigned division: {}").format(a),
            _(
                "For signed division, use `f_div_towards_zero`, `f_div_floor` and `f_div_euclid`."
            ),  # noqa: E501
        )

    if isinstance(b, ev.EUDVariable):
        return _eud_quot(a, b, **kwargs)

    elif isinstance(a, ev.EUDVariable):
        return _const_quot(b)(a, **kwargs)

    if b:
        q = a // b
    else:
        q = 0xFFFFFFFF, a
    try:
        vq = kwargs["ret"][0]
    except KeyError:
        vq = ev.EUDVariable()
    ev.SeqCompute([(vq, rt.SetTo, q)])
    return vq


def _rem(a, b, **kwargs):
    """Calculate (a%b)"""
    if ut.isUnproxyInstance(a, int) and a < 0:
        raise ut.EPError(
            _("Can't use negative dividend for unsigned division: {}").format(a),
            _(
                "For signed division, use `f_div_towards_zero`, `f_div_floor` and `f_div_euclid`."
            ),  # noqa: E501
        )
    if ut.isUnproxyInstance(b, int) and b < 0:
        raise ut.EPError(
            _("Can't use negative divider for unsigned division: {}").format(a),
            _(
                "For signed division, use `f_div_towards_zero`, `f_div_floor` and `f_div_euclid`."
            ),  # noqa: E501
        )

    if isinstance(b, ev.EUDVariable):
        return _eud_rem(a, b, **kwargs)

    elif isinstance(a, ev.EUDVariable):
        return _const_rem(b)(a, **kwargs)

    if b:
        m = a % b
    else:
        m = a
    try:
        vm = kwargs["ret"][0]
    except KeyError:
        vm = ev.EUDVariable()
    ev.SeqCompute([(vm, rt.SetTo, m)])
    return vm


# -------


def _const_mul(number: int) -> Callable:
    """
    f_constnum(a)(b) calculates b * a.

    :param number: Constant integer being multiplied to other numbers.
    :return: Function taking one parameter.
    """
    number &= 0xFFFFFFFF
    if not hasattr(_const_mul, "mulfdict"):
        from .bitwise import f_bitlshift

        @EUDFunc
        def _mul_1(x):
            return -x

        @EUDFunc
        def _mul0(x):
            return 0

        @EUDFunc
        def _mul1(x):
            return x

        def _mul_pow2(p):
            def pow2(x, **kwargs):
                return f_bitlshift(x, p, **kwargs)

            return pow2

        setattr(
            _const_mul,
            "mulfdict",
            {
                0xFFFFFFFF: _mul_1,
                0: _mul0,
                1: _mul1,
                2**1: _mul_pow2(1),
                2**2: _mul_pow2(2),
                2**3: _mul_pow2(3),
                2**4: _mul_pow2(4),
                2**5: _mul_pow2(5),
                2**6: _mul_pow2(6),
                2**7: _mul_pow2(7),
            },
        )

    mulfdict = getattr(_const_mul, "mulfdict")

    try:
        return mulfdict[number]
    except KeyError:

        @_EUDPredefineParam(1)
        @_EUDPredefineReturn(1, 2)
        @EUDFunc
        def _mulf(a):
            ret = _mulf._frets[0]
            ret << 0
            for i in ut._rand_lst(range(32)):
                if (2**i * number) & 0xFFFFFFFF == 0:
                    continue
                rt.RawTrigger(
                    conditions=a.AtLeastX(1, 2**i),
                    actions=ret.AddNumber(2**i * number),
                )
            # return ret

        mulfdict[number] = _mulf
        return _mulf


def _const_div(number: int) -> EUDTypedFuncN:
    """
    _const_div(a)(b) calculates (b // a, b % a)

    :param number: Constant positive integer to divide other numbers by.
    :return: Function taking one parameter.
    """
    if not hasattr(_const_div, "divfdict"):

        @EUDFunc
        def _div0(x):
            return -1, x

        @EUDFunc
        def _div1(x):
            return x, 0

        setattr(_const_div, "divfdict", {0: _div0, 1: _div1})

    divfdict = getattr(_const_div, "divfdict")

    try:
        return divfdict[number]
    except KeyError:

        @_EUDPredefineReturn(2)
        @_EUDPredefineParam(1, 2)
        @EUDFunc
        def _divf(a):
            quotient = _divf._frets[0]
            quotient << 0
            for i in range(31, -1, -1):
                # number too big
                if 2**i * number >= 2**32:
                    continue

                if number & (number - 1) == 0:
                    rt.RawTrigger(
                        conditions=a.AtLeastX(1, 2**i * number),
                        actions=quotient.AddNumber(2**i),
                    )
                else:
                    rt.RawTrigger(
                        conditions=a.AtLeast(2**i * number),
                        actions=[
                            a.SubtractNumber(2**i * number),
                            quotient.AddNumber(2**i),
                        ],
                    )
            if number & (number - 1) == 0:
                a &= number - 1
            # return quotient, a

        divfdict[number] = _divf
        return _divf


def _const_quot(number: int) -> Callable:
    """
    _const_quot(a)(b) calculates (b // a)

    :param number: Constant positive integer to divide other numbers by.
    :return: Function taking one parameter.
    """
    if not hasattr(_const_quot, "quotfdict"):

        @EUDFunc
        def _quot0(x):
            return -1

        @EUDFunc
        def _quot1(x):
            return x

        setattr(_const_quot, "quotfdict", {0: _quot0, 1: _quot1})

    quotfdict = getattr(_const_quot, "quotfdict")

    try:
        return quotfdict[number]
    except KeyError:
        if number & (number - 1) == 0:  # a // powOf2 = a >> log2(powOf2)

            @_EUDPredefineReturn(1)
            @_EUDPredefineParam(1)
            @EUDFunc
            def _quotf(quotient):
                ev.vbase.VariableBase.__irshift__(quotient, int(math.log2(number)))
                # return quotient

        else:

            @_EUDPredefineReturn(1)
            @EUDFunc
            def _quotf(a):
                quotient = _quotf._frets[0]
                quotient << 0
                for i in range(31, -1, -1):
                    # number too big
                    if 2**i * number >= 2**32:
                        continue

                    rt.RawTrigger(
                        conditions=a.AtLeast(2**i * number),
                        actions=[
                            a.SubtractNumber(2**i * number),
                            quotient.AddNumber(2**i),
                        ],
                    )
                # return quotient

        quotfdict[number] = _quotf
        return _quotf


def _const_rem(number: int) -> Callable:
    """
    _const_rem(a)(b) calculates (b // a)

    :param number: Constant positive integer to divide other numbers by.
    :return: Function taking one parameter.
    """
    if not hasattr(_const_rem, "remfdict"):

        @EUDFunc
        def _rem0(x):
            return x

        @EUDFunc
        def _rem1(x):
            return 0

        setattr(_const_rem, "remfdict", {0: _rem0, 1: _rem1})

    remfdict = getattr(_const_rem, "remfdict")

    try:
        return remfdict[number]
    except KeyError:
        if number & (number - 1) == 0:

            @_EUDPredefineReturn(1)
            @_EUDPredefineParam(1)
            @EUDFunc
            def _remf(remainder):
                remainder &= number - 1
                # return remainder

        else:

            @_EUDPredefineReturn(1)
            @_EUDPredefineParam(1)
            @EUDFunc
            def _remf(a):
                for i in range(31, -1, -1):
                    # number too big
                    if 2**i * number >= 2**32:
                        continue

                    rt.RawTrigger(
                        conditions=a.AtLeast(2**i * number),
                        actions=a.SubtractNumber(2**i * number),
                    )
                # return remainder

        remfdict[number] = _remf
        return _remf


# -------


@_EUDPredefineReturn(1)
@EUDFunc
def _eud_mul(a, b):
    ret = _eud_mul._frets[0]
    endmul, reset_nptr = ac.Forward(), ac.Forward()

    # Init
    rt.RawTrigger(actions=[ret.SetNumber(0), b.SetModifier(rt.Add)])
    remaining_bits = 0xFFFFFFFF

    # Run multiplication chain
    for i in range(32):
        remaining_bits -= 1 << i
        p1, p2, p3, p4 = (ac.Forward() for _ in range(4))
        p1 << rt.RawTrigger(
            nextptr=p2,
            conditions=a.AtLeastX(1, 2**i),
            actions=rt.SetNextPtr(p1, p3),
        )
        p3 << ev.VProc(b, [b.SetDest(ret), rt.SetNextPtr(p1, p2)])
        p2 << rt.NextTrigger()
        if i <= 30:
            acts = [
                rt.SetNextPtr(p2, endmul),
                rt.SetMemory(reset_nptr + 16, rt.SetTo, ut.EPD(p2 + 4)),
                rt.SetMemory(reset_nptr + 20, rt.SetTo, p4),
            ]
            rt.RawTrigger(
                nextptr=p4,
                conditions=a.ExactlyX(0, remaining_bits),
                actions=ut._rand_lst(acts),
            )
            p4 << ev.VProc(b, b.SetDest(b))  # b += b

    endmul << rt.RawTrigger(actions=[reset_nptr << rt.SetNextPtr(p1, p2)])
    # return ret


@EUDFunc
def _eud_div(a, b):
    ret, x = ev.EUDCreateVariables(2)

    # Init
    ev.SeqCompute([(ret, rt.SetTo, 0), (x, rt.SetTo, b)])

    # Chain ac.Forward decl
    chain_x0 = [ac.Forward() for _ in range(32)]
    chain_x1 = [ac.Forward() for _ in range(32)]
    chain = [ac.Forward() for _ in range(32)]

    # Fill in chain
    for i in range(32):
        ev.SeqCompute(
            [
                (ut.EPD(chain_x0[i]), rt.SetTo, x),
                (ut.EPD(chain_x1[i]), rt.SetTo, x),
            ]
        )

        # Skip if over 0x80000000
        p1, p2, p3 = ac.Forward(), ac.Forward(), ac.Forward()
        p1 << rt.RawTrigger(
            nextptr=p2,
            conditions=x.AtLeastX(1, 0x80000000),
            actions=rt.SetNextPtr(p1, p3),
        )
        p3 << rt.RawTrigger(nextptr=chain[i], actions=rt.SetNextPtr(p1, p2))
        p2 << rt.NextTrigger()

        ev.SeqCompute([(x, rt.Add, x)])

    # Run division chain
    for i in range(31, -1, -1):
        cx0, cx1 = ac.Forward(), ac.Forward()
        chain[i] << rt.RawTrigger(
            conditions=[cx0 << a.AtLeast(0)],
            actions=[cx1 << a.SubtractNumber(0), ret.AddNumber(2**i)],
        )

        chain_x0[i] << cx0 + 8
        chain_x1[i] << cx1 + 20

    return ret, a  # a : remainder


def _eud_quot(a, b, **kwargs):
    ret = kwargs.get("ret")
    if ret is not None:
        ret.append(_ev[4])
    quot = _eud_div(a, b, **kwargs)[0]
    return ret[0] if ret else quot


def _eud_rem(a, b, **kwargs):
    ret = kwargs.get("ret")
    if ret is not None:
        ret.insert(0, _ev[4])
    rem = _eud_div(a, b, **kwargs)[1]
    return ret[1] if ret else rem



from typing import Literal, TypeAlias

DefSfxDataDict = {
    "none": 0,
    "zerg/drone/zdrerr00.wav": 1,
    "misc/buzz.wav": 2,
    "misc/perror.wav": 3,
    "misc/zbldgplc.wav": 4,
    "misc/tbldgplc.wav": 5,
    "misc/pbldgplc.wav": 6,
    "misc/explolrg.wav": 7,
    "misc/explomed.wav": 8,
    "misc/explosm.wav": 9,
    "misc/explo1.wav": 10,
    "misc/explo2.wav": 11,
    "misc/explo3.wav": 12,
    "misc/explo4.wav": 13,
    "misc/explo5.wav": 14,
    "misc/button.wav": 15,
    "misc/burrowdn.wav": 16,
    "misc/burrowup.wav": 17,
    "misc/onfirsml.wav": 18,
    "misc/intonydus.wav": 19,
    "misc/outofgas.wav": 20,
    "misc/youwin.wav": 21,
    "misc/youlose.wav": 22,
    "misc/transmission.wav": 23,
    "misc/door/door1opn.wav": 24,
    "misc/door/door1cls.wav": 25,
    "misc/door/door2opn.wav": 26,
    "misc/door/door2cls.wav": 27,
    "misc/door/door3opn.wav": 28,
    "misc/door/door3cls.wav": 29,
    "misc/door/door4opn.wav": 30,
    "misc/door/door4cls.wav": 31,
    "misc/zrescue.wav": 32,
    "misc/trescue.wav": 33,
    "misc/prescue.wav": 34,
    "terran/scv/edrrep00.wav": 35,
    "terran/scv/edrrep01.wav": 36,
    "terran/scv/edrrep02.wav": 37,
    "terran/scv/edrrep03.wav": 38,
    "terran/scv/edrrep04.wav": 39,
    "misc/zovtra00.wav": 40,
    "misc/tdrtra00.wav": 41,
    "misc/pshtra00.wav": 42,
    "misc/zovtra01.wav": 43,
    "misc/tdrtra01.wav": 44,
    "misc/pshtra01.wav": 45,
    "misc/critters/jcrwht00.wav": 46,
    "misc/critters/jcrwht01.wav": 47,
    "misc/critters/jcrwht02.wav": 48,
    "misc/critters/jcrdth00.wav": 49,
    "misc/critters/lcrwht00.wav": 50,
    "misc/critters/lcrwht01.wav": 51,
    "misc/critters/lcrwht02.wav": 52,
    "misc/critters/lcrdth00.wav": 53,
    "misc/critters/bcrwht00.wav": 54,
    "misc/critters/bcrwht01.wav": 55,
    "misc/critters/bcrwht02.wav": 56,
    "misc/critters/bcrdth00.wav": 57,
    "bullet/parfir00.wav": 58,
    "bullet/zhyfir00.wav": 59,
    "bullet/zhyhit00.wav": 60,
    "bullet/zdrhit00.wav": 61,
    "bullet/laserhit.wav": 62,
    "bullet/pshield.wav": 63,
    "bullet/spooghit.wav": 64,
    "bullet/blastcan.wav": 65,
    "bullet/blastgn2.wav": 66,
    "bullet/zbghit00.wav": 67,
    "bullet/ttafir00.wav": 68,
    "bullet/tmafir00.wav": 69,
    "bullet/tgofir00.wav": 70,
    "bullet/zgufir00.wav": 71,
    "bullet/zguhit00.wav": 72,
    "bullet/laserb.wav": 73,
    "bullet/tphfi100.wav": 74,
    "bullet/lasrhit1.wav": 75,
    "bullet/lasrhit2.wav": 76,
    "bullet/lasrhit3.wav": 77,
    "bullet/zlufir00.wav": 78,
    "bullet/zluhit00.wav": 79,
    "bullet/hkmissle.wav": 80,
    "bullet/tgofi200.wav": 81,
    "bullet/tphfi200.wav": 82,
    "bullet/tnsfir00.wav": 83,
    "bullet/tnsfir00.wav (2)": 84,
    "bullet/tnshit00.wav": 85,
    "bullet/phoatt00.wav": 86,
    "bullet/phohit00.wav": 87,
    "bullet/psiblade.wav": 88,
    "bullet/psibolt.wav": 89,
    "bullet/zqufir00.wav": 90,
    "bullet/zquhit00.wav": 91,
    "bullet/zquhit01.wav": 92,
    "bullet/zquhit02.wav": 93,
    "bullet/tscfir00.wav": 94,
    "bullet/shockbmb.wav": 95,
    "bullet/ttafi200.wav": 96,
    "bullet/shcklnch.wav": 97,
    "bullet/tghfir00.wav": 98,
    "bullet/dragbull.wav": 99,
    "bullet/psahit00.wav": 100,
    "bullet/laserb.wav (2)": 101,
    "bullet/ptrfir00.wav": 102,
    "bullet/ptrfir01.wav": 103,
    "bullet/pzefir00.wav": 104,
    "bullet/tbafir00.wav": 105,
    "bullet/tvufir00.wav": 106,
    "bullet/tvuhit00.wav": 107,
    "bullet/tvuhit01.wav": 108,
    "bullet/tvuhit02.wav": 109,
    "bullet/zdeatt00.wav": 110,
    "bullet/uzefir00.wav": 111,
    "bullet/ukifir00.wav": 112,
    "bullet/zmufir00.wav": 113,
    "misc/zpwrdown.wav": 114,
    "misc/tpwrdown.wav": 115,
    "misc/ppwrdown.wav": 116,
    "zerg/advisor/zadupd00.wav": 117,
    "terran/advisor/tadupd00.wav": 118,
    "protoss/advisor/padupd00.wav": 119,
    "zerg/advisor/zadupd01.wav": 120,
    "terran/advisor/tadupd01.wav": 121,
    "protoss/advisor/padupd01.wav": 122,
    "zerg/advisor/zadupd02.wav": 123,
    "terran/advisor/tadupd02.wav": 124,
    "protoss/advisor/padupd02.wav": 125,
    "terran/advisor/tadupd03.wav": 126,
    "zerg/advisor/zadupd04.wav": 127,
    "terran/advisor/tadupd04.wav": 128,
    "protoss/advisor/padupd04.wav": 129,
    "terran/advisor/tadupd05.wav": 130,
    "terran/advisor/tadupd06.wav": 131,
    "terran/advisor/tadupd02.wav (2)": 132,
    "protoss/advisor/padupd06.wav": 133,
    "terran/advisor/tadupd07.wav": 134,
    "zerg/bldg/zchrdy00.wav": 135,
    "terran/scv/tscupd00.wav": 136,
    "zerg/drone/zdrerr00.wav (2)": 137,
    "zerg/drone/zdrerr00.wav (3)": 138,
    "misc/buzz.wav (2)": 139,
    "misc/perror.wav (2)": 140,
    "misc/zbldgplc.wav (2)": 141,
    "terran/advisor/taderr04.wav": 142,
    "terran/advisor/taderr03.wav": 143,
    "terran/advisor/taderr03.wav (2)": 144,
    "terran/advisor/taderr04.wav (2)": 145,
    "zerg/advisor/zaderr00.wav": 146,
    "zerg/advisor/zaderr00.wav (2)": 147,
    "terran/advisor/taderr00.wav": 148,
    "protoss/advisor/paderr00.wav": 149,
    "zerg/advisor/zaderr01.wav": 150,
    "terran/advisor/taderr01.wav": 151,
    "protoss/advisor/paderr01.wav": 152,
    "zerg/advisor/zaderr02.wav": 153,
    "terran/advisor/taderr02.wav": 154,
    "protoss/advisor/paderr02.wav": 155,
    "zerg/advisor/zaderr06.wav": 156,
    "terran/advisor/taderr06.wav": 157,
    "protoss/advisor/paderr06.wav": 158,
    "terran/scv/tscerr01.wav": 159,
    "terran/advisor/taderr04.wav (3)": 160,
    "protoss/probe/pprerr00.wav": 161,
    "terran/scv/tscerr00.wav": 162,
    "terran/advisor/taderr04.wav (4)": 163,
    "protoss/probe/pprerr01.wav": 164,
    "glue/mousedown2.wav": 165,
    "glue/mouseover.wav": 166,
    "glue/bnetclick.wav": 167,
    "glue/scorefill.wav": 168,
    "glue/scorefillend.wav": 169,
    "glue/countdown.wav": 170,
    "glue/swishlock.wav": 171,
    "glue/swishin.wav": 172,
    "glue/swishout.wav": 173,
    "terran/scv/tscmin00.wav": 174,
    "terran/scv/tscmin01.wav": 175,
    "terran/battle/tbardy00.wav": 176,
    "terran/battle/tbadth00.wav": 177,
    "terran/battle/tbayam01.wav": 178,
    "terran/battle/tbayam02.wav": 179,
    "terran/battle/tbapss00.wav": 180,
    "terran/battle/tbapss01.wav": 181,
    "terran/battle/tbapss02.wav": 182,
    "terran/battle/tbapss03.wav": 183,
    "terran/battle/tbapss04.wav": 184,
    "terran/battle/tbawht00.wav": 185,
    "terran/battle/tbawht01.wav": 186,
    "terran/battle/tbawht02.wav": 187,
    "terran/battle/tbawht03.wav": 188,
    "terran/battle/tbayes00.wav": 189,
    "terran/battle/tbayes01.wav": 190,
    "terran/battle/tbayes02.wav": 191,
    "terran/battle/tbayes03.wav": 192,
    "terran/civilian/tcvpss00.wav": 193,
    "terran/civilian/tcvpss01.wav": 194,
    "terran/civilian/tcvpss02.wav": 195,
    "terran/civilian/tcvpss03.wav": 196,
    "terran/civilian/tcvpss04.wav": 197,
    "terran/civilian/tcvwht00.wav": 198,
    "terran/civilian/tcvwht01.wav": 199,
    "terran/civilian/tcvwht02.wav": 200,
    "terran/civilian/tcvwht03.wav": 201,
    "terran/civilian/tcvyes00.wav": 202,
    "terran/civilian/tcvyes01.wav": 203,
    "terran/civilian/tcvyes02.wav": 204,
    "terran/civilian/tcvyes03.wav": 205,
    "terran/civilian/tcvyes04.wav": 206,
    "terran/civilian/tcvdth00.wav": 207,
    "terran/civilian/tcvrdy00.wav": 208,
    "terran/dropship/tdrrdy00.wav": 209,
    "terran/dropship/tdrdth00.wav": 210,
    "terran/dropship/tdrpss00.wav": 211,
    "terran/dropship/tdrpss01.wav": 212,
    "terran/dropship/tdrpss02.wav": 213,
    "terran/dropship/tdrpss03.wav": 214,
    "terran/dropship/tdrwht00.wav": 215,
    "terran/dropship/tdrwht01.wav": 216,
    "terran/dropship/tdrwht02.wav": 217,
    "terran/dropship/tdrwht03.wav": 218,
    "terran/dropship/tdryes00.wav": 219,
    "terran/dropship/tdryes01.wav": 220,
    "terran/dropship/tdryes02.wav": 221,
    "terran/dropship/tdryes03.wav": 222,
    "terran/dropship/tdryes04.wav": 223,
    "terran/dropship/tdryes05.wav": 224,
    "terran/ghost/tghrdy00.wav": 225,
    "terran/ghost/tghpss00.wav": 226,
    "terran/ghost/tghpss01.wav": 227,
    "terran/ghost/tghpss02.wav": 228,
    "terran/ghost/tghpss03.wav": 229,
    "terran/ghost/tghwht00.wav": 230,
    "terran/ghost/tghwht01.wav": 231,
    "terran/ghost/tghwht02.wav": 232,
    "terran/ghost/tghwht03.wav": 233,
    "terran/ghost/tghyes00.wav": 234,
    "terran/ghost/tghyes01.wav": 235,
    "terran/ghost/tghyes02.wav": 236,
    "terran/ghost/tghyes03.wav": 237,
    "terran/ghost/tghdth00.wav": 238,
    "terran/ghost/tghlas00.wav": 239,
    "terran/ghost/tghlkd00.wav": 240,
    "terran/goliath/tgordy00.wav": 241,
    "terran/goliath/tgopss00.wav": 242,
    "terran/goliath/tgopss01.wav": 243,
    "terran/goliath/tgopss02.wav": 244,
    "terran/goliath/tgopss03.wav": 245,
    "terran/goliath/tgopss04.wav": 246,
    "terran/goliath/tgopss05.wav": 247,
    "terran/goliath/tgowht00.wav": 248,
    "terran/goliath/tgowht01.wav": 249,
    "terran/goliath/tgowht02.wav": 250,
    "terran/goliath/tgowht03.wav": 251,
    "terran/goliath/tgoyes00.wav": 252,
    "terran/goliath/tgoyes01.wav": 253,
    "terran/goliath/tgoyes02.wav": 254,
    "terran/goliath/tgoyes03.wav": 255,
    "terran/phoenix/tphrdy00.wav": 256,
    "terran/phoenix/tphdth00.wav": 257,
    "terran/phoenix/tphpss00.wav": 258,
    "terran/phoenix/tphpss01.wav": 259,
    "terran/phoenix/tphpss02.wav": 260,
    "terran/phoenix/tphpss03.wav": 261,
    "terran/phoenix/tphpss04.wav": 262,
    "terran/phoenix/tphpss05.wav": 263,
    "terran/phoenix/tphpss06.wav": 264,
    "terran/phoenix/tphwht00.wav": 265,
    "terran/phoenix/tphwht01.wav": 266,
    "terran/phoenix/tphwht02.wav": 267,
    "terran/phoenix/tphwht03.wav": 268,
    "terran/phoenix/tphyes00.wav": 269,
    "terran/phoenix/tphyes01.wav": 270,
    "terran/phoenix/tphyes02.wav": 271,
    "terran/phoenix/tphyes03.wav": 272,
    "terran/phoenix/tphclo00.wav": 273,
    "terran/phoenix/tphclo01.wav": 274,
    "terran/marine/tmardy00.wav": 275,
    "terran/marine/tmadth00.wav": 276,
    "terran/marine/tmadth01.wav": 277,
    "terran/marine/tmasti00.wav": 278,
    "terran/marine/tmasti01.wav": 279,
    "terran/marine/tmapss00.wav": 280,
    "terran/marine/tmapss01.wav": 281,
    "terran/marine/tmapss02.wav": 282,
    "terran/marine/tmapss03.wav": 283,
    "terran/marine/tmapss04.wav": 284,
    "terran/marine/tmapss05.wav": 285,
    "terran/marine/tmapss06.wav": 286,
    "terran/marine/tmawht00.wav": 287,
    "terran/marine/tmawht01.wav": 288,
    "terran/marine/tmawht02.wav": 289,
    "terran/marine/tmawht03.wav": 290,
    "terran/marine/tmayes00.wav": 291,
    "terran/marine/tmayes01.wav": 292,
    "terran/marine/tmayes02.wav": 293,
    "terran/marine/tmayes03.wav": 294,
    "terran/firebat/tfbrdy00.wav": 295,
    "terran/firebat/tfbdth00.wav": 296,
    "terran/firebat/tfbdth01.wav": 297,
    "terran/firebat/tfbdth02.wav": 298,
    "terran/firebat/tfbwht00.wav": 299,
    "terran/firebat/tfbwht01.wav": 300,
    "terran/firebat/tfbwht02.wav": 301,
    "terran/firebat/tfbwht03.wav": 302,
    "terran/firebat/tfbpss00.wav": 303,
    "terran/firebat/tfbpss01.wav": 304,
    "terran/firebat/tfbpss02.wav": 305,
    "terran/firebat/tfbpss03.wav": 306,
    "terran/firebat/tfbpss04.wav": 307,
    "terran/firebat/tfbpss05.wav": 308,
    "terran/firebat/tfbpss06.wav": 309,
    "terran/firebat/tfbyes00.wav": 310,
    "terran/firebat/tfbyes01.wav": 311,
    "terran/firebat/tfbyes02.wav": 312,
    "terran/firebat/tfbyes03.wav": 313,
    "terran/firebat/tfbfir00.wav": 314,
    "terran/firebat/tfbfir01.wav": 315,
    "terran/tank/ttardy00.wav": 316,
    "terran/tank/ttadth00.wav": 317,
    "terran/tank/ttatra00.wav": 318,
    "terran/tank/ttatra01.wav": 319,
    "terran/tank/ttapss00.wav": 320,
    "terran/tank/ttapss01.wav": 321,
    "terran/tank/ttapss02.wav": 322,
    "terran/tank/ttapss03.wav": 323,
    "terran/tank/ttawht00.wav": 324,
    "terran/tank/ttawht01.wav": 325,
    "terran/tank/ttawht02.wav": 326,
    "terran/tank/ttawht03.wav": 327,
    "terran/tank/ttayes00.wav": 328,
    "terran/tank/ttayes01.wav": 329,
    "terran/tank/ttayes02.wav": 330,
    "terran/tank/ttayes03.wav": 331,
    "terran/vessel/tverdy00.wav": 332,
    "terran/vessel/tvepss00.wav": 333,
    "terran/vessel/tvepss01.wav": 334,
    "terran/vessel/tvepss02.wav": 335,
    "terran/vessel/tvepss03.wav": 336,
    "terran/vessel/tvepss04.wav": 337,
    "terran/vessel/tvepss05.wav": 338,
    "terran/vessel/tvepss06.wav": 339,
    "terran/vessel/tvewht00.wav": 340,
    "terran/vessel/tvewht01.wav": 341,
    "terran/vessel/tvewht02.wav": 342,
    "terran/vessel/tvewht03.wav": 343,
    "terran/vessel/tveyes00.wav": 344,
    "terran/vessel/tveyes01.wav": 345,
    "terran/vessel/tveyes02.wav": 346,
    "terran/vessel/tveyes03.wav": 347,
    "terran/vessel/tvedth00.wav": 348,
    "terran/vessel/tvedef00.wav": 349,
    "terran/vessel/tveemp00.wav": 350,
    "terran/vessel/tveirr00.wav": 351,
    "terran/vulture/tvurdy00.wav": 352,
    "terran/vulture/tvudth00.wav": 353,
    "terran/vulture/tvumin01.wav": 354,
    "terran/vulture/tvumin00.wav": 355,
    "terran/vulture/tvupss00.wav": 356,
    "terran/vulture/tvupss01.wav": 357,
    "terran/vulture/tvupss02.wav": 358,
    "terran/vulture/tvupss03.wav": 359,
    "terran/vulture/tvuwht00.wav": 360,
    "terran/vulture/tvuwht01.wav": 361,
    "terran/vulture/tvuwht02.wav": 362,
    "terran/vulture/tvuwht03.wav": 363,
    "terran/vulture/tvuyes00.wav": 364,
    "terran/vulture/tvuyes01.wav": 365,
    "terran/vulture/tvuyes02.wav": 366,
    "terran/vulture/tvuyes03.wav": 367,
    "terran/scv/tscrdy00.wav": 368,
    "terran/scv/tscdth00.wav": 369,
    "terran/scv/tscpss00.wav": 370,
    "terran/scv/tscpss01.wav": 371,
    "terran/scv/tscpss02.wav": 372,
    "terran/scv/tscpss03.wav": 373,
    "terran/scv/tscpss04.wav": 374,
    "terran/scv/tscpss05.wav": 375,
    "terran/scv/tscpss06.wav": 376,
    "terran/scv/tscwht00.wav": 377,
    "terran/scv/tscwht01.wav": 378,
    "terran/scv/tscwht02.wav": 379,
    "terran/scv/tscwht03.wav": 380,
    "terran/scv/tscyes00.wav": 381,
    "terran/scv/tscyes01.wav": 382,
    "terran/scv/tscyes02.wav": 383,
    "terran/scv/tscyes03.wav": 384,
    "terran/bldg/tacwht00.wav": 385,
    "terran/bldg/tclwht00.wav": 386,
    "terran/bldg/tcswht00.wav": 387,
    "terran/bldg/tcssca00.wav": 388,
    "terran/bldg/tddwht00.wav": 389,
    "terran/bldg/tglwht00.wav": 390,
    "misc/uicwht00.wav": 391,
    "terran/bldg/tmswht00.wav": 392,
    "terran/bldg/tmtwht00.wav": 393,
    "misc/unrwht00.wav": 394,
    "terran/bldg/trlwht00.wav": 395,
    "terran/bldg/tnswht00.wav": 396,
    "terran/bldg/tpgwht00.wav": 397,
    "terran/bldg/tplwht00.wav": 398,
    "misc/button.wav (2)": 399,
    "terran/bldg/trewht00.wav": 400,
    "terran/bldg/trfwht00.wav": 401,
    "terran/bldg/twpwht00.wav": 402,
    "terran/bldg/onfirlrg.wav": 403,
    "terran/scv/tsctra00.wav": 404,
    "terran/raynorm/uradth00.wav": 405,
    "terran/raynorm/uradth01.wav": 406,
    "terran/raynorm/urapss00.wav": 407,
    "terran/raynorm/urapss01.wav": 408,
    "terran/raynorm/urapss02.wav": 409,
    "terran/raynorm/urapss03.wav": 410,
    "terran/raynorm/urawht00.wav": 411,
    "terran/raynorm/urawht01.wav": 412,
    "terran/raynorm/urawht02.wav": 413,
    "terran/raynorm/urawht03.wav": 414,
    "terran/raynorm/urayes00.wav": 415,
    "terran/raynorm/urayes01.wav": 416,
    "terran/raynorm/urayes02.wav": 417,
    "terran/raynorm/urayes03.wav": 418,
    "terran/raynorv/urvpss00.wav": 419,
    "terran/raynorv/urvpss01.wav": 420,
    "terran/raynorv/urvpss02.wav": 421,
    "terran/raynorv/urvpss03.wav": 422,
    "terran/raynorv/urvwht00.wav": 423,
    "terran/raynorv/urvwht01.wav": 424,
    "terran/raynorv/urvwht02.wav": 425,
    "terran/raynorv/urvwht03.wav": 426,
    "terran/raynorv/urvyes00.wav": 427,
    "terran/raynorv/urvyes01.wav": 428,
    "terran/raynorv/urvyes02.wav": 429,
    "terran/raynorv/urvyes03.wav": 430,
    "terran/duket/udtpss00.wav": 431,
    "terran/duket/udtpss01.wav": 432,
    "terran/duket/udtpss02.wav": 433,
    "terran/duket/udtpss03.wav": 434,
    "terran/duket/udtpss04.wav": 435,
    "terran/duket/udtwht00.wav": 436,
    "terran/duket/udtwht01.wav": 437,
    "terran/duket/udtwht02.wav": 438,
    "terran/duket/udtwht03.wav": 439,
    "terran/duket/udtyes00.wav": 440,
    "terran/duket/udtyes01.wav": 441,
    "terran/duket/udtyes02.wav": 442,
    "terran/duket/udtyes03.wav": 443,
    "terran/dukeb/udupss00.wav": 444,
    "terran/dukeb/udupss01.wav": 445,
    "terran/dukeb/udupss02.wav": 446,
    "terran/dukeb/udupss03.wav": 447,
    "terran/dukeb/udupss04.wav": 448,
    "terran/dukeb/uduwht00.wav": 449,
    "terran/dukeb/uduwht01.wav": 450,
    "terran/dukeb/uduwht02.wav": 451,
    "terran/dukeb/uduwht03.wav": 452,
    "terran/dukeb/uduyes00.wav": 453,
    "terran/dukeb/uduyes01.wav": 454,
    "terran/dukeb/uduyes02.wav": 455,
    "terran/dukeb/uduyes03.wav": 456,
    "terran/kerrigan/ukepss00.wav": 457,
    "terran/kerrigan/ukepss01.wav": 458,
    "terran/kerrigan/ukepss02.wav": 459,
    "terran/kerrigan/ukepss03.wav": 460,
    "terran/kerrigan/ukepss04.wav": 461,
    "terran/kerrigan/ukewht00.wav": 462,
    "terran/kerrigan/ukewht01.wav": 463,
    "terran/kerrigan/ukewht02.wav": 464,
    "terran/kerrigan/ukewht03.wav": 465,
    "terran/kerrigan/ukeyes00.wav": 466,
    "terran/kerrigan/ukeyes01.wav": 467,
    "terran/kerrigan/ukeyes02.wav": 468,
    "terran/kerrigan/ukeyes03.wav": 469,
    "terran/kerrigan/ukedth00.wav": 470,
    "misc/liftoff.wav": 471,
    "misc/land.wav": 472,
    "protoss/bldg/pacwht00.wav": 473,
    "protoss/bldg/paswht00.wav": 474,
    "protoss/bldg/pbawht00.wav": 475,
    "protoss/bldg/pbewht00.wav": 476,
    "protoss/bldg/pciwht00.wav": 477,
    "protoss/bldg/pfowht00.wav": 478,
    "protoss/bldg/pgawht00.wav": 479,
    "protoss/bldg/pgcwht00.wav": 480,
    "protoss/bldg/pbaact00.wav": 481,
    "misc/button.wav (3)": 482,
    "protoss/bldg/pnawht00.wav": 483,
    "protoss/bldg/pnewht00.wav": 484,
    "protoss/bldg/ppbwht00.wav": 485,
    "misc/utmwht00.wav": 486,
    "protoss/bldg/ppywht00.wav": 487,
    "protoss/bldg/prowht00.wav": 488,
    "misc/upiwht00.wav": 489,
    "protoss/bldg/ptrwht00.wav": 490,
    "protoss/bldg/pwawht00.wav": 491,
    "protoss/dragoon/pdrrdy00.wav": 492,
    "protoss/dragoon/pdrdth00.wav": 493,
    "protoss/dragoon/pdrpss00.wav": 494,
    "protoss/dragoon/pdrpss01.wav": 495,
    "protoss/dragoon/pdrpss02.wav": 496,
    "protoss/dragoon/pdrpss03.wav": 497,
    "protoss/dragoon/pdrwht00.wav": 498,
    "protoss/dragoon/pdrwht01.wav": 499,
    "protoss/dragoon/pdrwht02.wav": 500,
    "protoss/dragoon/pdrwht03.wav": 501,
    "protoss/dragoon/pdrwht04.wav": 502,
    "protoss/dragoon/pdrwht05.wav": 503,
    "protoss/dragoon/pdrwht06.wav": 504,
    "protoss/dragoon/pdrwht07.wav": 505,
    "protoss/dragoon/pdryes00.wav": 506,
    "protoss/dragoon/pdryes01.wav": 507,
    "protoss/dragoon/pdryes02.wav": 508,
    "protoss/dragoon/pdryes03.wav": 509,
    "protoss/dragoon/pdryes04.wav": 510,
    "protoss/dragoon/pdryes05.wav": 511,
    "protoss/dragoon/pdryes06.wav": 512,
    "protoss/shuttle/pshrdy00.wav": 513,
    "protoss/shuttle/pshdth00.wav": 514,
    "protoss/shuttle/pshpss00.wav": 515,
    "protoss/shuttle/pshpss01.wav": 516,
    "protoss/shuttle/pshpss02.wav": 517,
    "protoss/shuttle/pshpss03.wav": 518,
    "protoss/shuttle/pshpss04.wav": 519,
    "protoss/shuttle/pshwht00.wav": 520,
    "protoss/shuttle/pshwht01.wav": 521,
    "protoss/shuttle/pshwht02.wav": 522,
    "protoss/shuttle/pshwht03.wav": 523,
    "protoss/shuttle/pshyes00.wav": 524,
    "protoss/shuttle/pshyes01.wav": 525,
    "protoss/shuttle/pshyes02.wav": 526,
    "protoss/shuttle/pshyes03.wav": 527,
    "protoss/shuttle/pshbld00.wav": 528,
    "protoss/shuttle/pshbld03.wav": 529,
    "protoss/shuttle/pshbld01.wav": 530,
    "protoss/shuttle/pshbld02.wav": 531,
    "protoss/shuttle/pshbld04.wav": 532,
    "protoss/scout/pscdth00.wav": 533,
    "protoss/scout/pscrdy00.wav": 534,
    "protoss/scout/pscpss00.wav": 535,
    "protoss/scout/pscpss01.wav": 536,
    "protoss/scout/pscpss02.wav": 537,
    "protoss/scout/pscpss03.wav": 538,
    "protoss/scout/pscpss04.wav": 539,
    "protoss/scout/pscwht00.wav": 540,
    "protoss/scout/pscwht01.wav": 541,
    "protoss/scout/pscwht02.wav": 542,
    "protoss/scout/pscwht03.wav": 543,
    "protoss/scout/pscyes00.wav": 544,
    "protoss/scout/pscyes01.wav": 545,
    "protoss/scout/pscyes02.wav": 546,
    "protoss/scout/pscyes03.wav": 547,
    "protoss/arbiter/pabcag00.wav": 548,
    "protoss/arbiter/pabrdy00.wav": 549,
    "protoss/arbiter/pabfol00.wav": 550,
    "protoss/arbiter/pabfol01.wav": 551,
    "protoss/arbiter/pabfol02.wav": 552,
    "protoss/arbiter/pabfol03.wav": 553,
    "protoss/arbiter/pabpss00.wav": 554,
    "protoss/arbiter/pabpss01.wav": 555,
    "protoss/arbiter/pabpss02.wav": 556,
    "protoss/arbiter/pabpss03.wav": 557,
    "protoss/arbiter/pabpss04.wav": 558,
    "protoss/arbiter/pabwht00.wav": 559,
    "protoss/arbiter/pabwht01.wav": 560,
    "protoss/arbiter/pabwht02.wav": 561,
    "protoss/arbiter/pabwht03.wav": 562,
    "protoss/arbiter/pabyes00.wav": 563,
    "protoss/arbiter/pabyes01.wav": 564,
    "protoss/arbiter/pabyes02.wav": 565,
    "protoss/arbiter/pabdth00.wav": 566,
    "protoss/archon/parrdy00.wav": 567,
    "protoss/archon/parmin00.wav": 568,
    "protoss/archon/parpss00.wav": 569,
    "protoss/archon/parpss01.wav": 570,
    "protoss/archon/parpss02.wav": 571,
    "protoss/archon/parpss03.wav": 572,
    "protoss/archon/parwht00.wav": 573,
    "protoss/archon/parwht01.wav": 574,
    "protoss/archon/parwht02.wav": 575,
    "protoss/archon/parwht03.wav": 576,
    "protoss/archon/paryes00.wav": 577,
    "protoss/archon/paryes01.wav": 578,
    "protoss/archon/paryes02.wav": 579,
    "protoss/archon/paryes03.wav": 580,
    "protoss/archon/pardth00.wav": 581,
    "protoss/carrier/pcardy00.wav": 582,
    "protoss/carrier/pcapss00.wav": 583,
    "protoss/carrier/pcapss01.wav": 584,
    "protoss/carrier/pcapss02.wav": 585,
    "protoss/carrier/pcapss03.wav": 586,
    "protoss/carrier/pcawht00.wav": 587,
    "protoss/carrier/pcawht01.wav": 588,
    "protoss/carrier/pcawht02.wav": 589,
    "protoss/carrier/pcawht03.wav": 590,
    "protoss/carrier/pcayes00.wav": 591,
    "protoss/carrier/pcayes01.wav": 592,
    "protoss/carrier/pcayes02.wav": 593,
    "protoss/carrier/pcayes03.wav": 594,
    "protoss/carrier/pcadth00.wav": 595,
    "protoss/carrier/pcadth01.wav": 596,
    "protoss/probe/pprrdy00.wav": 597,
    "protoss/probe/pprdth00.wav": 598,
    "protoss/probe/ppratt00.wav": 599,
    "protoss/probe/ppratt01.wav": 600,
    "protoss/probe/pprmin00.wav": 601,
    "protoss/probe/pprpss00.wav": 602,
    "protoss/probe/pprpss01.wav": 603,
    "protoss/probe/pprpss02.wav": 604,
    "protoss/probe/pprpss03.wav": 605,
    "protoss/probe/pprwht00.wav": 606,
    "protoss/probe/pprwht01.wav": 607,
    "protoss/probe/pprwht02.wav": 608,
    "protoss/probe/pprwht03.wav": 609,
    "protoss/probe/ppryes00.wav": 610,
    "protoss/probe/ppryes01.wav": 611,
    "protoss/probe/ppryes02.wav": 612,
    "protoss/probe/ppryes03.wav": 613,
    "protoss/intercep/pinlau00.wav": 614,
    "protoss/probe/pprpss00.wav (2)": 615,
    "protoss/templar/ptesum00.wav": 616,
    "protoss/templar/ptesum00.wav (2)": 617,
    "protoss/templar/ptehal00.wav": 618,
    "protoss/templar/ptehal01.wav": 619,
    "protoss/templar/ptesto00.wav": 620,
    "protoss/templar/ptesto01.wav": 621,
    "protoss/templar/pterdy00.wav": 622,
    "protoss/templar/ptepss00.wav": 623,
    "protoss/templar/ptepss01.wav": 624,
    "protoss/templar/ptepss02.wav": 625,
    "protoss/templar/ptepss03.wav": 626,
    "protoss/templar/ptewht00.wav": 627,
    "protoss/templar/ptewht01.wav": 628,
    "protoss/templar/ptewht02.wav": 629,
    "protoss/templar/ptewht03.wav": 630,
    "protoss/templar/pteyes00.wav": 631,
    "protoss/templar/pteyes01.wav": 632,
    "protoss/templar/pteyes02.wav": 633,
    "protoss/templar/pteyes03.wav": 634,
    "protoss/templar/ptedth00.wav": 635,
    "protoss/templar/ptemov00.wav": 636,
    "protoss/trilobyte/ptrrdy00.wav": 637,
    "protoss/trilobyte/ptrdth00.wav": 638,
    "protoss/trilobyte/ptrpss00.wav": 639,
    "protoss/trilobyte/ptrpss01.wav": 640,
    "protoss/trilobyte/ptrpss02.wav": 641,
    "protoss/trilobyte/ptrwht00.wav": 642,
    "protoss/trilobyte/ptrwht01.wav": 643,
    "protoss/trilobyte/ptrwht02.wav": 644,
    "protoss/trilobyte/ptrwht03.wav": 645,
    "protoss/trilobyte/ptryes00.wav": 646,
    "protoss/trilobyte/ptryes01.wav": 647,
    "protoss/trilobyte/ptryes02.wav": 648,
    "protoss/trilobyte/ptryes03.wav": 649,
    "protoss/witness/pwirdy00.wav": 650,
    "protoss/witness/pwidth00.wav": 651,
    "protoss/witness/pwidth01.wav": 652,
    "protoss/witness/pwipss00.wav": 653,
    "protoss/witness/pwipss01.wav": 654,
    "protoss/witness/pwipss02.wav": 655,
    "protoss/witness/pwipss03.wav": 656,
    "protoss/witness/pwipss04.wav": 657,
    "protoss/witness/pwiwht00.wav": 658,
    "protoss/witness/pwiwht01.wav": 659,
    "protoss/witness/pwiyes00.wav": 660,
    "protoss/witness/pwiyes01.wav": 661,
    "protoss/zealot/pzeatt00.wav": 662,
    "protoss/zealot/pzeatt01.wav": 663,
    "protoss/zealot/pzehit00.wav": 664,
    "protoss/zealot/pzerag00.wav": 665,
    "protoss/zealot/pzerdy00.wav": 666,
    "protoss/zealot/pzepss00.wav": 667,
    "protoss/zealot/pzepss01.wav": 668,
    "protoss/zealot/pzepss02.wav": 669,
    "protoss/zealot/pzewht00.wav": 670,
    "protoss/zealot/pzewht01.wav": 671,
    "protoss/zealot/pzewht02.wav": 672,
    "protoss/zealot/pzewht03.wav": 673,
    "protoss/zealot/pzeyes00.wav": 674,
    "protoss/zealot/pzeyes01.wav": 675,
    "protoss/zealot/pzeyes02.wav": 676,
    "protoss/zealot/pzeyes03.wav": 677,
    "protoss/zealot/pzedth00.wav": 678,
    "protoss/fenixd/ufdpss00.wav": 679,
    "protoss/fenixd/ufdpss01.wav": 680,
    "protoss/fenixd/ufdpss02.wav": 681,
    "protoss/fenixd/ufdpss03.wav": 682,
    "protoss/fenixd/ufdwht00.wav": 683,
    "protoss/fenixd/ufdwht01.wav": 684,
    "protoss/fenixd/ufdwht02.wav": 685,
    "protoss/fenixd/ufdwht03.wav": 686,
    "protoss/fenixd/ufdyes00.wav": 687,
    "protoss/fenixd/ufdyes01.wav": 688,
    "protoss/fenixd/ufdyes02.wav": 689,
    "protoss/fenixd/ufdyes03.wav": 690,
    "protoss/fenixz/ufepss00.wav": 691,
    "protoss/fenixz/ufepss01.wav": 692,
    "protoss/fenixz/ufepss02.wav": 693,
    "protoss/fenixz/ufepss03.wav": 694,
    "protoss/fenixz/ufewht00.wav": 695,
    "protoss/fenixz/ufewht01.wav": 696,
    "protoss/fenixz/ufewht02.wav": 697,
    "protoss/fenixz/ufewht03.wav": 698,
    "protoss/fenixz/ufeyes00.wav": 699,
    "protoss/fenixz/ufeyes01.wav": 700,
    "protoss/fenixz/ufeyes02.wav": 701,
    "protoss/fenixz/ufeyes03.wav": 702,
    "protoss/gantrithor/utcpss00.wav": 703,
    "protoss/gantrithor/utcpss01.wav": 704,
    "protoss/gantrithor/utcpss02.wav": 705,
    "protoss/gantrithor/utcpss03.wav": 706,
    "protoss/gantrithor/utcwht00.wav": 707,
    "protoss/gantrithor/utcwht01.wav": 708,
    "protoss/gantrithor/utcwht02.wav": 709,
    "protoss/gantrithor/utcwht03.wav": 710,
    "protoss/gantrithor/utcyes00.wav": 711,
    "protoss/gantrithor/utcyes01.wav": 712,
    "protoss/gantrithor/utcyes02.wav": 713,
    "protoss/gantrithor/utcyes03.wav": 714,
    "protoss/tassadar/utapss00.wav": 715,
    "protoss/tassadar/utapss01.wav": 716,
    "protoss/tassadar/utapss02.wav": 717,
    "protoss/tassadar/utapss03.wav": 718,
    "protoss/tassadar/utawht00.wav": 719,
    "protoss/tassadar/utawht01.wav": 720,
    "protoss/tassadar/utawht02.wav": 721,
    "protoss/tassadar/utawht03.wav": 722,
    "protoss/tassadar/utayes00.wav": 723,
    "protoss/tassadar/utayes01.wav": 724,
    "protoss/tassadar/utayes02.wav": 725,
    "protoss/tassadar/utayes03.wav": 726,
    "protoss/tassadar/utadth00.wav": 727,
    "protoss/darktemplar/pdtrdy00.wav": 728,
    "protoss/darktemplar/pdtpss00.wav": 729,
    "protoss/darktemplar/pdtpss01.wav": 730,
    "protoss/darktemplar/pdtpss02.wav": 731,
    "protoss/darktemplar/pdtpss03.wav": 732,
    "protoss/darktemplar/pdtwht00.wav": 733,
    "protoss/darktemplar/pdtwht01.wav": 734,
    "protoss/darktemplar/pdtwht02.wav": 735,
    "protoss/darktemplar/pdtwht03.wav": 736,
    "protoss/darktemplar/pdtyes00.wav": 737,
    "protoss/darktemplar/pdtyes01.wav": 738,
    "protoss/darktemplar/pdtyes02.wav": 739,
    "protoss/darktemplar/pdtyes03.wav": 740,
    "protoss/darktemplar/pdtdth00.wav": 741,
    "protoss/zeratul/uzepss00.wav": 742,
    "protoss/zeratul/uzepss01.wav": 743,
    "protoss/zeratul/uzepss02.wav": 744,
    "protoss/zeratul/uzepss03.wav": 745,
    "protoss/zeratul/uzewht00.wav": 746,
    "protoss/zeratul/uzewht01.wav": 747,
    "protoss/zeratul/uzewht02.wav": 748,
    "protoss/zeratul/uzewht03.wav": 749,
    "protoss/zeratul/uzeyes00.wav": 750,
    "protoss/zeratul/uzeyes01.wav": 751,
    "protoss/zeratul/uzeyes02.wav": 752,
    "protoss/zeratul/uzeyes03.wav": 753,
    "protoss/zeratul/uzedth00.wav": 754,
    "zerg/bldg/zchwht00.wav": 755,
    "zerg/bldg/zcbwht00.wav": 756,
    "zerg/bldg/zevwht00.wav": 757,
    "zerg/bldg/zfcwht00.wav": 758,
    "zerg/bldg/zhawht00.wav": 759,
    "zerg/bldg/zhiwht00.wav": 760,
    "zerg/bldg/zigwht00.wav": 761,
    "zerg/bldg/zlrwht00.wav": 762,
    "zerg/bldg/zluwht00.wav": 763,
    "zerg/bldg/zmcwht00.wav": 764,
    "protoss/bldg/pnawht00.wav (2)": 765,
    "zerg/bldg/zmhwht00.wav": 766,
    "zerg/bldg/znewht00.wav": 767,
    "zerg/bldg/znywht00.wav": 768,
    "zerg/bldg/zo1wht00.wav": 769,
    "zerg/bldg/zrcwht00.wav": 770,
    "zerg/bldg/zsbwht00.wav": 771,
    "zerg/bldg/zscwht00.wav": 772,
    "zerg/bldg/zspwht00.wav": 773,
    "zerg/bldg/zbldgdth.wav": 774,
    "zerg/avenger/zavrdy00.wav": 775,
    "zerg/avenger/zavdth00.wav": 776,
    "zerg/avenger/zavatt00.wav": 777,
    "zerg/avenger/zavhit00.wav": 778,
    "zerg/avenger/zavpss00.wav": 779,
    "zerg/avenger/zavpss01.wav": 780,
    "zerg/avenger/zavwht00.wav": 781,
    "zerg/avenger/zavwht01.wav": 782,
    "zerg/avenger/zavyes00.wav": 783,
    "zerg/avenger/zavyes01.wav": 784,
    "zerg/broodling/zbrdth00.wav": 785,
    "zerg/broodling/zbratt00.wav": 786,
    "zerg/broodling/zbrrdy00.wav": 787,
    "zerg/broodling/zbrpss00.wav": 788,
    "zerg/broodling/zbrpss01.wav": 789,
    "zerg/broodling/zbrpss02.wav": 790,
    "zerg/broodling/zbrpss03.wav": 791,
    "zerg/broodling/zbrwht00.wav": 792,
    "zerg/broodling/zbrwht01.wav": 793,
    "zerg/broodling/zbrwht02.wav": 794,
    "zerg/broodling/zbrwht03.wav": 795,
    "zerg/broodling/zbryes00.wav": 796,
    "zerg/broodling/zbryes01.wav": 797,
    "zerg/broodling/zbryes02.wav": 798,
    "zerg/bugguy/zbgrdy00.wav": 799,
    "zerg/bugguy/zbgrdy00.wav (2)": 800,
    "zerg/bugguy/zbgpss00.wav": 801,
    "zerg/bugguy/zbgpss01.wav": 802,
    "zerg/bugguy/zbgpss02.wav": 803,
    "zerg/bugguy/zbgpss03.wav": 804,
    "zerg/bugguy/zbgwht00.wav": 805,
    "zerg/bugguy/zbgwht01.wav": 806,
    "zerg/bugguy/zbgwht02.wav": 807,
    "zerg/bugguy/zbgwht03.wav": 808,
    "zerg/bugguy/zbgyes00.wav": 809,
    "zerg/bugguy/zbgyes01.wav": 810,
    "zerg/bugguy/zbgyes02.wav": 811,
    "zerg/bugguy/zbgyes03.wav": 812,
    "zerg/defiler/zdecon00.wav": 813,
    "zerg/defiler/zderdy00.wav": 814,
    "zerg/defiler/zdedth00.wav": 815,
    "zerg/defiler/zdeblo00.wav": 816,
    "zerg/defiler/zdeblo01.wav": 817,
    "zerg/defiler/zdepss00.wav": 818,
    "zerg/defiler/zdepss01.wav": 819,
    "zerg/defiler/zdepss02.wav": 820,
    "zerg/defiler/zdewht00.wav": 821,
    "zerg/defiler/zdewht01.wav": 822,
    "zerg/defiler/zdewht02.wav": 823,
    "zerg/defiler/zdeyes00.wav": 824,
    "zerg/defiler/zdeyes01.wav": 825,
    "zerg/defiler/zdeyes02.wav": 826,
    "zerg/egg/zegrdy00.wav": 827,
    "zerg/egg/zegwht00.wav": 828,
    "zerg/egg/zegwht01.wav": 829,
    "zerg/egg/zegdth00.wav": 830,
    "zerg/egg/zegpss00.wav": 831,
    "zerg/drone/zdrrdy00.wav": 832,
    "zerg/drone/zdrdth00.wav": 833,
    "zerg/drone/zdrpss00.wav": 834,
    "zerg/drone/zdrpss01.wav": 835,
    "zerg/drone/zdrpss02.wav": 836,
    "zerg/drone/zdrwht00.wav": 837,
    "zerg/drone/zdrwht01.wav": 838,
    "zerg/drone/zdrwht02.wav": 839,
    "zerg/drone/zdrwht03.wav": 840,
    "zerg/drone/zdrwht04.wav": 841,
    "zerg/drone/zdryes00.wav": 842,
    "zerg/drone/zdryes01.wav": 843,
    "zerg/drone/zdryes02.wav": 844,
    "zerg/drone/zdryes03.wav": 845,
    "zerg/drone/zdryes04.wav": 846,
    "zerg/drone/zdrmin00.wav": 847,
    "zerg/larva/zladth00.wav": 848,
    "terran/advisor/taderr04.wav (5)": 849,
    "zerg/larva/zlapss00.wav": 850,
    "zerg/larva/zlawht00.wav": 851,
    "zerg/guardian/zgudth00.wav": 852,
    "zerg/guardian/zgupss00.wav": 853,
    "zerg/guardian/zgupss01.wav": 854,
    "zerg/guardian/zgupss02.wav": 855,
    "zerg/guardian/zgupss03.wav": 856,
    "zerg/guardian/zgurdy00.wav": 857,
    "zerg/guardian/zguwht00.wav": 858,
    "zerg/guardian/zguwht01.wav": 859,
    "zerg/guardian/zguwht02.wav": 860,
    "zerg/guardian/zguwht03.wav": 861,
    "zerg/guardian/zguyes00.wav": 862,
    "zerg/guardian/zguyes01.wav": 863,
    "zerg/guardian/zguyes02.wav": 864,
    "zerg/guardian/zguyes03.wav": 865,
    "zerg/hydra/zhyrdy00.wav": 866,
    "zerg/hydra/zhydth00.wav": 867,
    "zerg/hydra/zhypss00.wav": 868,
    "zerg/hydra/zhypss01.wav": 869,
    "zerg/hydra/zhywht00.wav": 870,
    "zerg/hydra/zhywht01.wav": 871,
    "zerg/hydra/zhywht02.wav": 872,
    "zerg/hydra/zhyyes00.wav": 873,
    "zerg/hydra/zhyyes01.wav": 874,
    "zerg/hydra/zhyyes02.wav": 875,
    "zerg/hydra/zhyyes03.wav": 876,
    "zerg/ultra/zulror00.wav": 877,
    "zerg/ultra/zuldth00.wav": 878,
    "zerg/ultra/zulpss00.wav": 879,
    "zerg/ultra/zulpss01.wav": 880,
    "zerg/ultra/zulpss02.wav": 881,
    "zerg/ultra/zulrdy00.wav": 882,
    "zerg/ultra/zulwht00.wav": 883,
    "zerg/ultra/zulwht01.wav": 884,
    "zerg/ultra/zulwht02.wav": 885,
    "zerg/ultra/zulwht03.wav": 886,
    "zerg/ultra/zulyes00.wav": 887,
    "zerg/ultra/zulyes01.wav": 888,
    "zerg/ultra/zulyes02.wav": 889,
    "zerg/ultra/zulyes03.wav": 890,
    "zerg/ultra/zulatt00.wav": 891,
    "zerg/ultra/zulatt01.wav": 892,
    "zerg/ultra/zulatt02.wav": 893,
    "zerg/ultra/zulhit00.wav": 894,
    "zerg/ultra/zulhit01.wav": 895,
    "zerg/zergling/zzedth00.wav": 896,
    "zerg/zergling/zzepss00.wav": 897,
    "zerg/zergling/zzepss01.wav": 898,
    "zerg/zergling/zzepss02.wav": 899,
    "zerg/zergling/zzerdy00.wav": 900,
    "zerg/zergling/zzewht00.wav": 901,
    "zerg/zergling/zzewht01.wav": 902,
    "zerg/zergling/zzewht02.wav": 903,
    "zerg/zergling/zzewht03.wav": 904,
    "zerg/zergling/zzeyes00.wav": 905,
    "zerg/zergling/zzeyes01.wav": 906,
    "zerg/zergling/zzeyes02.wav": 907,
    "zerg/zergling/zzeyes03.wav": 908,
    "zerg/overlord/zovrdy00.wav": 909,
    "zerg/overlord/zovdth00.wav": 910,
    "zerg/overlord/zovpss00.wav": 911,
    "zerg/overlord/zovwht00.wav": 912,
    "zerg/overlord/zovwht01.wav": 913,
    "zerg/overlord/zovwht02.wav": 914,
    "zerg/overlord/zovwht03.wav": 915,
    "zerg/overlord/zovyes00.wav": 916,
    "zerg/overlord/zovyes01.wav": 917,
    "zerg/overlord/zovyes02.wav": 918,
    "zerg/overlord/zovyes03.wav": 919,
    "zerg/queen/zqutag00.wav": 920,
    "zerg/queen/zqutag01.wav": 921,
    "zerg/queen/zquswm00.wav": 922,
    "zerg/queen/zquswm01.wav": 923,
    "zerg/queen/zquens00.wav": 924,
    "zerg/queen/zqudth00.wav": 925,
    "zerg/queen/zqudth01.wav": 926,
    "zerg/queen/zqudth02.wav": 927,
    "zerg/queen/zqurdy00.wav": 928,
    "zerg/queen/zqupss00.wav": 929,
    "zerg/queen/zqupss01.wav": 930,
    "zerg/queen/zqupss02.wav": 931,
    "zerg/queen/zqupss03.wav": 932,
    "zerg/queen/zquwht00.wav": 933,
    "zerg/queen/zquwht01.wav": 934,
    "zerg/queen/zquwht02.wav": 935,
    "zerg/queen/zquwht03.wav": 936,
    "zerg/queen/zquyes00.wav": 937,
    "zerg/queen/zquyes01.wav": 938,
    "zerg/queen/zquyes02.wav": 939,
    "zerg/queen/zquyes03.wav": 940,
    "zerg/mutalid/zmurdy00.wav": 941,
    "zerg/mutalid/zmudth00.wav": 942,
    "zerg/mutalid/zmupss00.wav": 943,
    "zerg/mutalid/zmupss01.wav": 944,
    "zerg/mutalid/zmupss02.wav": 945,
    "zerg/mutalid/zmupss03.wav": 946,
    "zerg/mutalid/zmuwht00.wav": 947,
    "zerg/mutalid/zmuwht01.wav": 948,
    "zerg/mutalid/zmuwht02.wav": 949,
    "zerg/mutalid/zmuwht03.wav": 950,
    "zerg/mutalid/zmuyes00.wav": 951,
    "zerg/mutalid/zmuyes01.wav": 952,
    "zerg/mutalid/zmuyes02.wav": 953,
    "zerg/mutalid/zmuyes03.wav": 954,
    "zerg/zergkerri/ukipss00.wav": 955,
    "zerg/zergkerri/ukipss01.wav": 956,
    "zerg/zergkerri/ukipss02.wav": 957,
    "zerg/zergkerri/ukipss03.wav": 958,
    "zerg/zergkerri/ukiwht00.wav": 959,
    "zerg/zergkerri/ukiwht01.wav": 960,
    "zerg/zergkerri/ukiwht02.wav": 961,
    "zerg/zergkerri/ukiwht03.wav": 962,
    "zerg/zergkerri/ukiyes00.wav": 963,
    "zerg/zergkerri/ukiyes01.wav": 964,
    "zerg/zergkerri/ukiyes02.wav": 965,
    "zerg/zergkerri/ukiyes03.wav": 966,
    "zerg/zergkerri/ukidth00.wav": 967,
    "misc/critters/pbwht01.wav": 968,
    "misc/critters/pbwht02.wav": 969,
    "misc/critters/pbwht03.wav": 970,
    "misc/critters/pbdeath01.wav": 971,
    "misc/critters/scwht01.wav": 972,
    "misc/critters/scwht02.wav": 973,
    "misc/critters/scwht03.wav": 974,
    "misc/critters/scdeath01.wav": 975,
    "misc/critters/terwht01.wav": 976,
    "misc/critters/terwht02.wav": 977,
    "misc/critters/terwht03.wav": 978,
    "misc/critters/terdeath01.wav": 979,
    "terran/duran/tdnpss00.wav": 980,
    "terran/duran/tdnpss01.wav": 981,
    "terran/duran/tdnpss02.wav": 982,
    "terran/duran/tdnpss03.wav": 983,
    "terran/duran/tdnpss04.wav": 984,
    "terran/duran/tdnpss05.wav": 985,
    "terran/duran/tdnpss06.wav": 986,
    "terran/duran/tdnpss07.wav": 987,
    "terran/duran/tdnpss08.wav": 988,
    "terran/duran/tdnwht00.wav": 989,
    "terran/duran/tdnwht01.wav": 990,
    "terran/duran/tdnwht02.wav": 991,
    "terran/duran/tdnwht03.wav": 992,
    "terran/duran/tdnyes00.wav": 993,
    "terran/duran/tdnyes01.wav": 994,
    "terran/duran/tdnyes02.wav": 995,
    "terran/duran/tdnyes03.wav": 996,
    "terran/duran/tdndth00.wav": 997,
    "terran/medic/tmedcure.wav": 998,
    "terran/medic/tmdrdy00.wav": 999,
    "terran/medic/tmddth00.wav": 1000,
    "terran/medic/tmdwht00.wav": 1001,
    "terran/medic/tmdwht01.wav": 1002,
    "terran/medic/tmdwht02.wav": 1003,
    "terran/medic/tmdwht03.wav": 1004,
    "terran/medic/tmdyes00.wav": 1005,
    "terran/medic/tmdyes01.wav": 1006,
    "terran/medic/tmdyes02.wav": 1007,
    "terran/medic/tmdyes03.wav": 1008,
    "terran/medic/tmdpss00.wav": 1009,
    "terran/medic/tmdpss01.wav": 1010,
    "terran/medic/tmdpss02.wav": 1011,
    "terran/medic/tmdpss03.wav": 1012,
    "terran/medic/tmdpss04.wav": 1013,
    "terran/medic/tmdpss05.wav": 1014,
    "terran/medic/tmdpss06.wav": 1015,
    "terran/medic/tmedflsh.wav": 1016,
    "terran/medic/tmedrest.wav": 1017,
    "terran/medic/tmedheal.wav": 1018,
    "terran/medic/miopia1.wav": 1019,
    "terran/frigate/afteron.wav": 1020,
    "terran/frigate/afteroff.wav": 1021,
    "bullet/tfrhit.wav": 1022,
    "bullet/tfrshoot.wav": 1023,
    "terran/frigate/tvkrdy00.wav": 1024,
    "terran/frigate/tvkpss00.wav": 1025,
    "terran/frigate/tvkpss01.wav": 1026,
    "terran/frigate/tvkpss02.wav": 1027,
    "terran/frigate/tvkpss03.wav": 1028,
    "terran/frigate/tvkpss04.wav": 1029,
    "terran/frigate/tvkpss05.wav": 1030,
    "terran/frigate/tvkwht00.wav": 1031,
    "terran/frigate/tvkwht01.wav": 1032,
    "terran/frigate/tvkwht02.wav": 1033,
    "terran/frigate/tvkwht03.wav": 1034,
    "terran/frigate/tvkyes00.wav": 1035,
    "terran/frigate/tvkyes01.wav": 1036,
    "terran/frigate/tvkyes02.wav": 1037,
    "terran/frigate/tvkyes03.wav": 1038,
    "terran/frigate/tvkyes04.wav": 1039,
    "terran/frigate/tvkdth00.wav": 1040,
    "protoss/corsair/pcordy00.wav": 1041,
    "protoss/corsair/pcorhit1.wav": 1042,
    "protoss/corsair/pcorhit2.wav": 1043,
    "protoss/corsair/pcowht00.wav": 1044,
    "protoss/corsair/pcowht01.wav": 1045,
    "protoss/corsair/pcowht02.wav": 1046,
    "protoss/corsair/pcowht03.wav": 1047,
    "protoss/corsair/pcoyes00.wav": 1048,
    "protoss/corsair/pcoyes01.wav": 1049,
    "protoss/corsair/pcoyes02.wav": 1050,
    "protoss/corsair/pcoyes03.wav": 1051,
    "protoss/corsair/pcopss00.wav": 1052,
    "protoss/corsair/pcopss01.wav": 1053,
    "protoss/corsair/pcopss02.wav": 1054,
    "protoss/corsair/pcopss03.wav": 1055,
    "protoss/corsair/pcopss04.wav": 1056,
    "protoss/corsair/pcopss05.wav": 1057,
    "protoss/corsair/pcopss06.wav": 1058,
    "protoss/corsair/pcorweb1.wav": 1059,
    "protoss/corsair/pcorlasr2.wav": 1060,
    "protoss/darchon/feedback.wav": 1061,
    "protoss/darchon/mind.wav": 1062,
    "protoss/darchon/paraattk.wav": 1063,
    "protoss/darchon/parahit.wav": 1064,
    "protoss/darchon/pdardy00.wav": 1065,
    "protoss/darchon/pdrdth00.wav": 1066,
    "protoss/darchon/pdapss00.wav": 1067,
    "protoss/darchon/pdapss01.wav": 1068,
    "protoss/darchon/pdapss02.wav": 1069,
    "protoss/darchon/pdapss03.wav": 1070,
    "protoss/darchon/pdawht00.wav": 1071,
    "protoss/darchon/pdawht01.wav": 1072,
    "protoss/darchon/pdawht02.wav": 1073,
    "protoss/darchon/pdawht03.wav": 1074,
    "protoss/darchon/pdayes00.wav": 1075,
    "protoss/darchon/pdayes01.wav": 1076,
    "protoss/darchon/pdayes02.wav": 1077,
    "protoss/darchon/pdayes03.wav": 1078,
    "zerg/lurker/zlurdy00.wav": 1079,
    "zerg/lurker/zludth00.wav": 1080,
    "zerg/lurker/zlupss00.wav": 1081,
    "zerg/lurker/zlupss01.wav": 1082,
    "zerg/lurker/zlupss02.wav": 1083,
    "zerg/lurker/zlupss03.wav": 1084,
    "zerg/lurker/zluwht00.wav": 1085,
    "zerg/lurker/zluwht01.wav": 1086,
    "zerg/lurker/zluwht02.wav": 1087,
    "zerg/lurker/zluwht03.wav": 1088,
    "zerg/lurker/zluyes00.wav": 1089,
    "zerg/lurker/zluyes01.wav": 1090,
    "zerg/lurker/zluyes02.wav": 1091,
    "zerg/lurker/zluyes03.wav": 1092,
    "zerg/lurker/zluburrw.wav": 1093,
    "zerg/devourer/firesuck.wav": 1094,
    "zerg/devourer/goophit.wav": 1095,
    "zerg/devourer/zdvrdy00.wav": 1096,
    "zerg/devourer/zdvdth00.wav": 1097,
    "zerg/devourer/zdvpss00.wav": 1098,
    "zerg/devourer/zdvpss01.wav": 1099,
    "zerg/devourer/zdvpss02.wav": 1100,
    "zerg/devourer/zdvwht00.wav": 1101,
    "zerg/devourer/zdvwht01.wav": 1102,
    "zerg/devourer/zdvwht02.wav": 1103,
    "zerg/devourer/zdvyes00.wav": 1104,
    "zerg/devourer/zdvyes01.wav": 1105,
    "zerg/devourer/zdvyes02.wav": 1106,
    "zerg/devourer/zdvyes03.wav": 1107,
    "bullet/zlrkfir1.wav": 1108,
    "bullet/zlrkfir2.wav": 1109,
    "bullet/zlrkhit1.wav": 1110,
    "bullet/zlrkhit2.wav": 1111,
    "zerg/zergduran/zdnpss00.wav": 1112,
    "zerg/zergduran/zdnpss01.wav": 1113,
    "zerg/zergduran/zdnpss02.wav": 1114,
    "zerg/zergduran/zdnpss03.wav": 1115,
    "zerg/zergduran/zdnpss04.wav": 1116,
    "zerg/zergduran/zdnpss05.wav": 1117,
    "zerg/zergduran/zdnpss06.wav": 1118,
    "zerg/zergduran/zdnpss07.wav": 1119,
    "zerg/zergduran/zdnpss08.wav": 1120,
    "zerg/zergduran/zdnwht00.wav": 1121,
    "zerg/zergduran/zdnwht01.wav": 1122,
    "zerg/zergduran/zdnwht02.wav": 1123,
    "zerg/zergduran/zdnwht03.wav": 1124,
    "zerg/zergduran/zdnyes00.wav": 1125,
    "zerg/zergduran/zdnyes01.wav": 1126,
    "zerg/zergduran/zdnyes02.wav": 1127,
    "zerg/zergduran/zdnyes03.wav": 1128,
    "zerg/zergduran/zdndth00.wav": 1129,
    "protoss/artanis/patpss00.wav": 1130,
    "protoss/artanis/patpss01.wav": 1131,
    "protoss/artanis/patpss02.wav": 1132,
    "protoss/artanis/patpss03.wav": 1133,
    "protoss/artanis/patpss04.wav": 1134,
    "protoss/artanis/patpss05.wav": 1135,
    "protoss/artanis/patwht00.wav": 1136,
    "protoss/artanis/patwht01.wav": 1137,
    "protoss/artanis/patwht02.wav": 1138,
    "protoss/artanis/patwht03.wav": 1139,
    "protoss/artanis/patyes00.wav": 1140,
    "protoss/artanis/patyes01.wav": 1141,
    "protoss/artanis/patyes02.wav": 1142,
    "protoss/artanis/patyes03.wav": 1143,
}

DefaultSfxData: TypeAlias = Literal[
    "None",
    "zerg/drone/zdrerr00.wav",
    "misc/buzz.wav",
    "misc/perror.wav",
    "misc/zbldgplc.wav",
    "misc/tbldgplc.wav",
    "misc/pbldgplc.wav",
    "misc/explolrg.wav",
    "misc/explomed.wav",
    "misc/explosm.wav",
    "misc/explo1.wav",
    "misc/explo2.wav",
    "misc/explo3.wav",
    "misc/explo4.wav",
    "misc/explo5.wav",
    "misc/button.wav",
    "misc/burrowdn.wav",
    "misc/burrowup.wav",
    "misc/onfirsml.wav",
    "misc/intonydus.wav",
    "misc/outofgas.wav",
    "misc/youwin.wav",
    "misc/youlose.wav",
    "misc/transmission.wav",
    "misc/door/door1opn.wav",
    "misc/door/door1cls.wav",
    "misc/door/door2opn.wav",
    "misc/door/door2cls.wav",
    "misc/door/door3opn.wav",
    "misc/door/door3cls.wav",
    "misc/door/door4opn.wav",
    "misc/door/door4cls.wav",
    "misc/zrescue.wav",
    "misc/trescue.wav",
    "misc/prescue.wav",
    "terran/scv/edrrep00.wav",
    "terran/scv/edrrep01.wav",
    "terran/scv/edrrep02.wav",
    "terran/scv/edrrep03.wav",
    "terran/scv/edrrep04.wav",
    "misc/zovtra00.wav",
    "misc/tdrtra00.wav",
    "misc/pshtra00.wav",
    "misc/zovtra01.wav",
    "misc/tdrtra01.wav",
    "misc/pshtra01.wav",
    "misc/critters/jcrwht00.wav",
    "misc/critters/jcrwht01.wav",
    "misc/critters/jcrwht02.wav",
    "misc/critters/jcrdth00.wav",
    "misc/critters/lcrwht00.wav",
    "misc/critters/lcrwht01.wav",
    "misc/critters/lcrwht02.wav",
    "misc/critters/lcrdth00.wav",
    "misc/critters/bcrwht00.wav",
    "misc/critters/bcrwht01.wav",
    "misc/critters/bcrwht02.wav",
    "misc/critters/bcrdth00.wav",
    "bullet/parfir00.wav",
    "bullet/zhyfir00.wav",
    "bullet/zhyhit00.wav",
    "bullet/zdrhit00.wav",
    "bullet/laserhit.wav",
    "bullet/pshield.wav",
    "bullet/spooghit.wav",
    "bullet/blastcan.wav",
    "bullet/blastgn2.wav",
    "bullet/zbghit00.wav",
    "bullet/ttafir00.wav",
    "bullet/tmafir00.wav",
    "bullet/tgofir00.wav",
    "bullet/zgufir00.wav",
    "bullet/zguhit00.wav",
    "bullet/laserb.wav",
    "bullet/tphfi100.wav",
    "bullet/lasrhit1.wav",
    "bullet/lasrhit2.wav",
    "bullet/lasrhit3.wav",
    "bullet/zlufir00.wav",
    "bullet/zluhit00.wav",
    "bullet/hkmissle.wav",
    "bullet/tgofi200.wav",
    "bullet/tphfi200.wav",
    "bullet/tnsfir00.wav",
    "bullet/tnsfir00.wav (2)",
    "bullet/tnshit00.wav",
    "bullet/phoatt00.wav",
    "bullet/phohit00.wav",
    "bullet/psiblade.wav",
    "bullet/psibolt.wav",
    "bullet/zqufir00.wav",
    "bullet/zquhit00.wav",
    "bullet/zquhit01.wav",
    "bullet/zquhit02.wav",
    "bullet/tscfir00.wav",
    "bullet/shockbmb.wav",
    "bullet/ttafi200.wav",
    "bullet/shcklnch.wav",
    "bullet/tghfir00.wav",
    "bullet/dragbull.wav",
    "bullet/psahit00.wav",
    "bullet/laserb.wav (2)",
    "bullet/ptrfir00.wav",
    "bullet/ptrfir01.wav",
    "bullet/pzefir00.wav",
    "bullet/tbafir00.wav",
    "bullet/tvufir00.wav",
    "bullet/tvuhit00.wav",
    "bullet/tvuhit01.wav",
    "bullet/tvuhit02.wav",
    "bullet/zdeatt00.wav",
    "bullet/uzefir00.wav",
    "bullet/ukifir00.wav",
    "bullet/zmufir00.wav",
    "misc/zpwrdown.wav",
    "misc/tpwrdown.wav",
    "misc/ppwrdown.wav",
    "zerg/advisor/zadupd00.wav",
    "terran/advisor/tadupd00.wav",
    "protoss/advisor/padupd00.wav",
    "zerg/advisor/zadupd01.wav",
    "terran/advisor/tadupd01.wav",
    "protoss/advisor/padupd01.wav",
    "zerg/advisor/zadupd02.wav",
    "terran/advisor/tadupd02.wav",
    "protoss/advisor/padupd02.wav",
    "terran/advisor/tadupd03.wav",
    "zerg/advisor/zadupd04.wav",
    "terran/advisor/tadupd04.wav",
    "protoss/advisor/padupd04.wav",
    "terran/advisor/tadupd05.wav",
    "terran/advisor/tadupd06.wav",
    "terran/advisor/tadupd02.wav (2)",
    "protoss/advisor/padupd06.wav",
    "terran/advisor/tadupd07.wav",
    "zerg/bldg/zchrdy00.wav",
    "terran/scv/tscupd00.wav",
    "zerg/drone/zdrerr00.wav (2)",
    "zerg/drone/zdrerr00.wav (3)",
    "misc/buzz.wav (2)",
    "misc/perror.wav (2)",
    "misc/zbldgplc.wav (2)",
    "terran/advisor/taderr04.wav",
    "terran/advisor/taderr03.wav",
    "terran/advisor/taderr03.wav (2)",
    "terran/advisor/taderr04.wav (2)",
    "zerg/advisor/zaderr00.wav",
    "zerg/advisor/zaderr00.wav (2)",
    "terran/advisor/taderr00.wav",
    "protoss/advisor/paderr00.wav",
    "zerg/advisor/zaderr01.wav",
    "terran/advisor/taderr01.wav",
    "protoss/advisor/paderr01.wav",
    "zerg/advisor/zaderr02.wav",
    "terran/advisor/taderr02.wav",
    "protoss/advisor/paderr02.wav",
    "zerg/advisor/zaderr06.wav",
    "terran/advisor/taderr06.wav",
    "protoss/advisor/paderr06.wav",
    "terran/scv/tscerr01.wav",
    "terran/advisor/taderr04.wav (3)",
    "protoss/probe/pprerr00.wav",
    "terran/scv/tscerr00.wav",
    "terran/advisor/taderr04.wav (4)",
    "protoss/probe/pprerr01.wav",
    "glue/mousedown2.wav",
    "glue/mouseover.wav",
    "glue/bnetclick.wav",
    "glue/scorefill.wav",
    "glue/scorefillend.wav",
    "glue/countdown.wav",
    "glue/swishlock.wav",
    "glue/swishin.wav",
    "glue/swishout.wav",
    "terran/scv/tscmin00.wav",
    "terran/scv/tscmin01.wav",
    "terran/battle/tbardy00.wav",
    "terran/battle/tbadth00.wav",
    "terran/battle/tbayam01.wav",
    "terran/battle/tbayam02.wav",
    "terran/battle/tbapss00.wav",
    "terran/battle/tbapss01.wav",
    "terran/battle/tbapss02.wav",
    "terran/battle/tbapss03.wav",
    "terran/battle/tbapss04.wav",
    "terran/battle/tbawht00.wav",
    "terran/battle/tbawht01.wav",
    "terran/battle/tbawht02.wav",
    "terran/battle/tbawht03.wav",
    "terran/battle/tbayes00.wav",
    "terran/battle/tbayes01.wav",
    "terran/battle/tbayes02.wav",
    "terran/battle/tbayes03.wav",
    "terran/civilian/tcvpss00.wav",
    "terran/civilian/tcvpss01.wav",
    "terran/civilian/tcvpss02.wav",
    "terran/civilian/tcvpss03.wav",
    "terran/civilian/tcvpss04.wav",
    "terran/civilian/tcvwht00.wav",
    "terran/civilian/tcvwht01.wav",
    "terran/civilian/tcvwht02.wav",
    "terran/civilian/tcvwht03.wav",
    "terran/civilian/tcvyes00.wav",
    "terran/civilian/tcvyes01.wav",
    "terran/civilian/tcvyes02.wav",
    "terran/civilian/tcvyes03.wav",
    "terran/civilian/tcvyes04.wav",
    "terran/civilian/tcvdth00.wav",
    "terran/civilian/tcvrdy00.wav",
    "terran/dropship/tdrrdy00.wav",
    "terran/dropship/tdrdth00.wav",
    "terran/dropship/tdrpss00.wav",
    "terran/dropship/tdrpss01.wav",
    "terran/dropship/tdrpss02.wav",
    "terran/dropship/tdrpss03.wav",
    "terran/dropship/tdrwht00.wav",
    "terran/dropship/tdrwht01.wav",
    "terran/dropship/tdrwht02.wav",
    "terran/dropship/tdrwht03.wav",
    "terran/dropship/tdryes00.wav",
    "terran/dropship/tdryes01.wav",
    "terran/dropship/tdryes02.wav",
    "terran/dropship/tdryes03.wav",
    "terran/dropship/tdryes04.wav",
    "terran/dropship/tdryes05.wav",
    "terran/ghost/tghrdy00.wav",
    "terran/ghost/tghpss00.wav",
    "terran/ghost/tghpss01.wav",
    "terran/ghost/tghpss02.wav",
    "terran/ghost/tghpss03.wav",
    "terran/ghost/tghwht00.wav",
    "terran/ghost/tghwht01.wav",
    "terran/ghost/tghwht02.wav",
    "terran/ghost/tghwht03.wav",
    "terran/ghost/tghyes00.wav",
    "terran/ghost/tghyes01.wav",
    "terran/ghost/tghyes02.wav",
    "terran/ghost/tghyes03.wav",
    "terran/ghost/tghdth00.wav",
    "terran/ghost/tghlas00.wav",
    "terran/ghost/tghlkd00.wav",
    "terran/goliath/tgordy00.wav",
    "terran/goliath/tgopss00.wav",
    "terran/goliath/tgopss01.wav",
    "terran/goliath/tgopss02.wav",
    "terran/goliath/tgopss03.wav",
    "terran/goliath/tgopss04.wav",
    "terran/goliath/tgopss05.wav",
    "terran/goliath/tgowht00.wav",
    "terran/goliath/tgowht01.wav",
    "terran/goliath/tgowht02.wav",
    "terran/goliath/tgowht03.wav",
    "terran/goliath/tgoyes00.wav",
    "terran/goliath/tgoyes01.wav",
    "terran/goliath/tgoyes02.wav",
    "terran/goliath/tgoyes03.wav",
    "terran/phoenix/tphrdy00.wav",
    "terran/phoenix/tphdth00.wav",
    "terran/phoenix/tphpss00.wav",
    "terran/phoenix/tphpss01.wav",
    "terran/phoenix/tphpss02.wav",
    "terran/phoenix/tphpss03.wav",
    "terran/phoenix/tphpss04.wav",
    "terran/phoenix/tphpss05.wav",
    "terran/phoenix/tphpss06.wav",
    "terran/phoenix/tphwht00.wav",
    "terran/phoenix/tphwht01.wav",
    "terran/phoenix/tphwht02.wav",
    "terran/phoenix/tphwht03.wav",
    "terran/phoenix/tphyes00.wav",
    "terran/phoenix/tphyes01.wav",
    "terran/phoenix/tphyes02.wav",
    "terran/phoenix/tphyes03.wav",
    "terran/phoenix/tphclo00.wav",
    "terran/phoenix/tphclo01.wav",
    "terran/marine/tmardy00.wav",
    "terran/marine/tmadth00.wav",
    "terran/marine/tmadth01.wav",
    "terran/marine/tmasti00.wav",
    "terran/marine/tmasti01.wav",
    "terran/marine/tmapss00.wav",
    "terran/marine/tmapss01.wav",
    "terran/marine/tmapss02.wav",
    "terran/marine/tmapss03.wav",
    "terran/marine/tmapss04.wav",
    "terran/marine/tmapss05.wav",
    "terran/marine/tmapss06.wav",
    "terran/marine/tmawht00.wav",
    "terran/marine/tmawht01.wav",
    "terran/marine/tmawht02.wav",
    "terran/marine/tmawht03.wav",
    "terran/marine/tmayes00.wav",
    "terran/marine/tmayes01.wav",
    "terran/marine/tmayes02.wav",
    "terran/marine/tmayes03.wav",
    "terran/firebat/tfbrdy00.wav",
    "terran/firebat/tfbdth00.wav",
    "terran/firebat/tfbdth01.wav",
    "terran/firebat/tfbdth02.wav",
    "terran/firebat/tfbwht00.wav",
    "terran/firebat/tfbwht01.wav",
    "terran/firebat/tfbwht02.wav",
    "terran/firebat/tfbwht03.wav",
    "terran/firebat/tfbpss00.wav",
    "terran/firebat/tfbpss01.wav",
    "terran/firebat/tfbpss02.wav",
    "terran/firebat/tfbpss03.wav",
    "terran/firebat/tfbpss04.wav",
    "terran/firebat/tfbpss05.wav",
    "terran/firebat/tfbpss06.wav",
    "terran/firebat/tfbyes00.wav",
    "terran/firebat/tfbyes01.wav",
    "terran/firebat/tfbyes02.wav",
    "terran/firebat/tfbyes03.wav",
    "terran/firebat/tfbfir00.wav",
    "terran/firebat/tfbfir01.wav",
    "terran/tank/ttardy00.wav",
    "terran/tank/ttadth00.wav",
    "terran/tank/ttatra00.wav",
    "terran/tank/ttatra01.wav",
    "terran/tank/ttapss00.wav",
    "terran/tank/ttapss01.wav",
    "terran/tank/ttapss02.wav",
    "terran/tank/ttapss03.wav",
    "terran/tank/ttawht00.wav",
    "terran/tank/ttawht01.wav",
    "terran/tank/ttawht02.wav",
    "terran/tank/ttawht03.wav",
    "terran/tank/ttayes00.wav",
    "terran/tank/ttayes01.wav",
    "terran/tank/ttayes02.wav",
    "terran/tank/ttayes03.wav",
    "terran/vessel/tverdy00.wav",
    "terran/vessel/tvepss00.wav",
    "terran/vessel/tvepss01.wav",
    "terran/vessel/tvepss02.wav",
    "terran/vessel/tvepss03.wav",
    "terran/vessel/tvepss04.wav",
    "terran/vessel/tvepss05.wav",
    "terran/vessel/tvepss06.wav",
    "terran/vessel/tvewht00.wav",
    "terran/vessel/tvewht01.wav",
    "terran/vessel/tvewht02.wav",
    "terran/vessel/tvewht03.wav",
    "terran/vessel/tveyes00.wav",
    "terran/vessel/tveyes01.wav",
    "terran/vessel/tveyes02.wav",
    "terran/vessel/tveyes03.wav",
    "terran/vessel/tvedth00.wav",
    "terran/vessel/tvedef00.wav",
    "terran/vessel/tveemp00.wav",
    "terran/vessel/tveirr00.wav",
    "terran/vulture/tvurdy00.wav",
    "terran/vulture/tvudth00.wav",
    "terran/vulture/tvumin01.wav",
    "terran/vulture/tvumin00.wav",
    "terran/vulture/tvupss00.wav",
    "terran/vulture/tvupss01.wav",
    "terran/vulture/tvupss02.wav",
    "terran/vulture/tvupss03.wav",
    "terran/vulture/tvuwht00.wav",
    "terran/vulture/tvuwht01.wav",
    "terran/vulture/tvuwht02.wav",
    "terran/vulture/tvuwht03.wav",
    "terran/vulture/tvuyes00.wav",
    "terran/vulture/tvuyes01.wav",
    "terran/vulture/tvuyes02.wav",
    "terran/vulture/tvuyes03.wav",
    "terran/scv/tscrdy00.wav",
    "terran/scv/tscdth00.wav",
    "terran/scv/tscpss00.wav",
    "terran/scv/tscpss01.wav",
    "terran/scv/tscpss02.wav",
    "terran/scv/tscpss03.wav",
    "terran/scv/tscpss04.wav",
    "terran/scv/tscpss05.wav",
    "terran/scv/tscpss06.wav",
    "terran/scv/tscwht00.wav",
    "terran/scv/tscwht01.wav",
    "terran/scv/tscwht02.wav",
    "terran/scv/tscwht03.wav",
    "terran/scv/tscyes00.wav",
    "terran/scv/tscyes01.wav",
    "terran/scv/tscyes02.wav",
    "terran/scv/tscyes03.wav",
    "terran/bldg/tacwht00.wav",
    "terran/bldg/tclwht00.wav",
    "terran/bldg/tcswht00.wav",
    "terran/bldg/tcssca00.wav",
    "terran/bldg/tddwht00.wav",
    "terran/bldg/tglwht00.wav",
    "misc/uicwht00.wav",
    "terran/bldg/tmswht00.wav",
    "terran/bldg/tmtwht00.wav",
    "misc/unrwht00.wav",
    "terran/bldg/trlwht00.wav",
    "terran/bldg/tnswht00.wav",
    "terran/bldg/tpgwht00.wav",
    "terran/bldg/tplwht00.wav",
    "misc/button.wav (2)",
    "terran/bldg/trewht00.wav",
    "terran/bldg/trfwht00.wav",
    "terran/bldg/twpwht00.wav",
    "terran/bldg/onfirlrg.wav",
    "terran/scv/tsctra00.wav",
    "terran/raynorm/uradth00.wav",
    "terran/raynorm/uradth01.wav",
    "terran/raynorm/urapss00.wav",
    "terran/raynorm/urapss01.wav",
    "terran/raynorm/urapss02.wav",
    "terran/raynorm/urapss03.wav",
    "terran/raynorm/urawht00.wav",
    "terran/raynorm/urawht01.wav",
    "terran/raynorm/urawht02.wav",
    "terran/raynorm/urawht03.wav",
    "terran/raynorm/urayes00.wav",
    "terran/raynorm/urayes01.wav",
    "terran/raynorm/urayes02.wav",
    "terran/raynorm/urayes03.wav",
    "terran/raynorv/urvpss00.wav",
    "terran/raynorv/urvpss01.wav",
    "terran/raynorv/urvpss02.wav",
    "terran/raynorv/urvpss03.wav",
    "terran/raynorv/urvwht00.wav",
    "terran/raynorv/urvwht01.wav",
    "terran/raynorv/urvwht02.wav",
    "terran/raynorv/urvwht03.wav",
    "terran/raynorv/urvyes00.wav",
    "terran/raynorv/urvyes01.wav",
    "terran/raynorv/urvyes02.wav",
    "terran/raynorv/urvyes03.wav",
    "terran/duket/udtpss00.wav",
    "terran/duket/udtpss01.wav",
    "terran/duket/udtpss02.wav",
    "terran/duket/udtpss03.wav",
    "terran/duket/udtpss04.wav",
    "terran/duket/udtwht00.wav",
    "terran/duket/udtwht01.wav",
    "terran/duket/udtwht02.wav",
    "terran/duket/udtwht03.wav",
    "terran/duket/udtyes00.wav",
    "terran/duket/udtyes01.wav",
    "terran/duket/udtyes02.wav",
    "terran/duket/udtyes03.wav",
    "terran/dukeb/udupss00.wav",
    "terran/dukeb/udupss01.wav",
    "terran/dukeb/udupss02.wav",
    "terran/dukeb/udupss03.wav",
    "terran/dukeb/udupss04.wav",
    "terran/dukeb/uduwht00.wav",
    "terran/dukeb/uduwht01.wav",
    "terran/dukeb/uduwht02.wav",
    "terran/dukeb/uduwht03.wav",
    "terran/dukeb/uduyes00.wav",
    "terran/dukeb/uduyes01.wav",
    "terran/dukeb/uduyes02.wav",
    "terran/dukeb/uduyes03.wav",
    "terran/kerrigan/ukepss00.wav",
    "terran/kerrigan/ukepss01.wav",
    "terran/kerrigan/ukepss02.wav",
    "terran/kerrigan/ukepss03.wav",
    "terran/kerrigan/ukepss04.wav",
    "terran/kerrigan/ukewht00.wav",
    "terran/kerrigan/ukewht01.wav",
    "terran/kerrigan/ukewht02.wav",
    "terran/kerrigan/ukewht03.wav",
    "terran/kerrigan/ukeyes00.wav",
    "terran/kerrigan/ukeyes01.wav",
    "terran/kerrigan/ukeyes02.wav",
    "terran/kerrigan/ukeyes03.wav",
    "terran/kerrigan/ukedth00.wav",
    "misc/liftoff.wav",
    "misc/land.wav",
    "protoss/bldg/pacwht00.wav",
    "protoss/bldg/paswht00.wav",
    "protoss/bldg/pbawht00.wav",
    "protoss/bldg/pbewht00.wav",
    "protoss/bldg/pciwht00.wav",
    "protoss/bldg/pfowht00.wav",
    "protoss/bldg/pgawht00.wav",
    "protoss/bldg/pgcwht00.wav",
    "protoss/bldg/pbaact00.wav",
    "misc/button.wav (3)",
    "protoss/bldg/pnawht00.wav",
    "protoss/bldg/pnewht00.wav",
    "protoss/bldg/ppbwht00.wav",
    "misc/utmwht00.wav",
    "protoss/bldg/ppywht00.wav",
    "protoss/bldg/prowht00.wav",
    "misc/upiwht00.wav",
    "protoss/bldg/ptrwht00.wav",
    "protoss/bldg/pwawht00.wav",
    "protoss/dragoon/pdrrdy00.wav",
    "protoss/dragoon/pdrdth00.wav",
    "protoss/dragoon/pdrpss00.wav",
    "protoss/dragoon/pdrpss01.wav",
    "protoss/dragoon/pdrpss02.wav",
    "protoss/dragoon/pdrpss03.wav",
    "protoss/dragoon/pdrwht00.wav",
    "protoss/dragoon/pdrwht01.wav",
    "protoss/dragoon/pdrwht02.wav",
    "protoss/dragoon/pdrwht03.wav",
    "protoss/dragoon/pdrwht04.wav",
    "protoss/dragoon/pdrwht05.wav",
    "protoss/dragoon/pdrwht06.wav",
    "protoss/dragoon/pdrwht07.wav",
    "protoss/dragoon/pdryes00.wav",
    "protoss/dragoon/pdryes01.wav",
    "protoss/dragoon/pdryes02.wav",
    "protoss/dragoon/pdryes03.wav",
    "protoss/dragoon/pdryes04.wav",
    "protoss/dragoon/pdryes05.wav",
    "protoss/dragoon/pdryes06.wav",
    "protoss/shuttle/pshrdy00.wav",
    "protoss/shuttle/pshdth00.wav",
    "protoss/shuttle/pshpss00.wav",
    "protoss/shuttle/pshpss01.wav",
    "protoss/shuttle/pshpss02.wav",
    "protoss/shuttle/pshpss03.wav",
    "protoss/shuttle/pshpss04.wav",
    "protoss/shuttle/pshwht00.wav",
    "protoss/shuttle/pshwht01.wav",
    "protoss/shuttle/pshwht02.wav",
    "protoss/shuttle/pshwht03.wav",
    "protoss/shuttle/pshyes00.wav",
    "protoss/shuttle/pshyes01.wav",
    "protoss/shuttle/pshyes02.wav",
    "protoss/shuttle/pshyes03.wav",
    "protoss/shuttle/pshbld00.wav",
    "protoss/shuttle/pshbld03.wav",
    "protoss/shuttle/pshbld01.wav",
    "protoss/shuttle/pshbld02.wav",
    "protoss/shuttle/pshbld04.wav",
    "protoss/scout/pscdth00.wav",
    "protoss/scout/pscrdy00.wav",
    "protoss/scout/pscpss00.wav",
    "protoss/scout/pscpss01.wav",
    "protoss/scout/pscpss02.wav",
    "protoss/scout/pscpss03.wav",
    "protoss/scout/pscpss04.wav",
    "protoss/scout/pscwht00.wav",
    "protoss/scout/pscwht01.wav",
    "protoss/scout/pscwht02.wav",
    "protoss/scout/pscwht03.wav",
    "protoss/scout/pscyes00.wav",
    "protoss/scout/pscyes01.wav",
    "protoss/scout/pscyes02.wav",
    "protoss/scout/pscyes03.wav",
    "protoss/arbiter/pabcag00.wav",
    "protoss/arbiter/pabrdy00.wav",
    "protoss/arbiter/pabfol00.wav",
    "protoss/arbiter/pabfol01.wav",
    "protoss/arbiter/pabfol02.wav",
    "protoss/arbiter/pabfol03.wav",
    "protoss/arbiter/pabpss00.wav",
    "protoss/arbiter/pabpss01.wav",
    "protoss/arbiter/pabpss02.wav",
    "protoss/arbiter/pabpss03.wav",
    "protoss/arbiter/pabpss04.wav",
    "protoss/arbiter/pabwht00.wav",
    "protoss/arbiter/pabwht01.wav",
    "protoss/arbiter/pabwht02.wav",
    "protoss/arbiter/pabwht03.wav",
    "protoss/arbiter/pabyes00.wav",
    "protoss/arbiter/pabyes01.wav",
    "protoss/arbiter/pabyes02.wav",
    "protoss/arbiter/pabdth00.wav",
    "protoss/archon/parrdy00.wav",
    "protoss/archon/parmin00.wav",
    "protoss/archon/parpss00.wav",
    "protoss/archon/parpss01.wav",
    "protoss/archon/parpss02.wav",
    "protoss/archon/parpss03.wav",
    "protoss/archon/parwht00.wav",
    "protoss/archon/parwht01.wav",
    "protoss/archon/parwht02.wav",
    "protoss/archon/parwht03.wav",
    "protoss/archon/paryes00.wav",
    "protoss/archon/paryes01.wav",
    "protoss/archon/paryes02.wav",
    "protoss/archon/paryes03.wav",
    "protoss/archon/pardth00.wav",
    "protoss/carrier/pcardy00.wav",
    "protoss/carrier/pcapss00.wav",
    "protoss/carrier/pcapss01.wav",
    "protoss/carrier/pcapss02.wav",
    "protoss/carrier/pcapss03.wav",
    "protoss/carrier/pcawht00.wav",
    "protoss/carrier/pcawht01.wav",
    "protoss/carrier/pcawht02.wav",
    "protoss/carrier/pcawht03.wav",
    "protoss/carrier/pcayes00.wav",
    "protoss/carrier/pcayes01.wav",
    "protoss/carrier/pcayes02.wav",
    "protoss/carrier/pcayes03.wav",
    "protoss/carrier/pcadth00.wav",
    "protoss/carrier/pcadth01.wav",
    "protoss/probe/pprrdy00.wav",
    "protoss/probe/pprdth00.wav",
    "protoss/probe/ppratt00.wav",
    "protoss/probe/ppratt01.wav",
    "protoss/probe/pprmin00.wav",
    "protoss/probe/pprpss00.wav",
    "protoss/probe/pprpss01.wav",
    "protoss/probe/pprpss02.wav",
    "protoss/probe/pprpss03.wav",
    "protoss/probe/pprwht00.wav",
    "protoss/probe/pprwht01.wav",
    "protoss/probe/pprwht02.wav",
    "protoss/probe/pprwht03.wav",
    "protoss/probe/ppryes00.wav",
    "protoss/probe/ppryes01.wav",
    "protoss/probe/ppryes02.wav",
    "protoss/probe/ppryes03.wav",
    "protoss/intercep/pinlau00.wav",
    "protoss/probe/pprpss00.wav (2)",
    "protoss/templar/ptesum00.wav",
    "protoss/templar/ptesum00.wav (2)",
    "protoss/templar/ptehal00.wav",
    "protoss/templar/ptehal01.wav",
    "protoss/templar/ptesto00.wav",
    "protoss/templar/ptesto01.wav",
    "protoss/templar/pterdy00.wav",
    "protoss/templar/ptepss00.wav",
    "protoss/templar/ptepss01.wav",
    "protoss/templar/ptepss02.wav",
    "protoss/templar/ptepss03.wav",
    "protoss/templar/ptewht00.wav",
    "protoss/templar/ptewht01.wav",
    "protoss/templar/ptewht02.wav",
    "protoss/templar/ptewht03.wav",
    "protoss/templar/pteyes00.wav",
    "protoss/templar/pteyes01.wav",
    "protoss/templar/pteyes02.wav",
    "protoss/templar/pteyes03.wav",
    "protoss/templar/ptedth00.wav",
    "protoss/templar/ptemov00.wav",
    "protoss/trilobyte/ptrrdy00.wav",
    "protoss/trilobyte/ptrdth00.wav",
    "protoss/trilobyte/ptrpss00.wav",
    "protoss/trilobyte/ptrpss01.wav",
    "protoss/trilobyte/ptrpss02.wav",
    "protoss/trilobyte/ptrwht00.wav",
    "protoss/trilobyte/ptrwht01.wav",
    "protoss/trilobyte/ptrwht02.wav",
    "protoss/trilobyte/ptrwht03.wav",
    "protoss/trilobyte/ptryes00.wav",
    "protoss/trilobyte/ptryes01.wav",
    "protoss/trilobyte/ptryes02.wav",
    "protoss/trilobyte/ptryes03.wav",
    "protoss/witness/pwirdy00.wav",
    "protoss/witness/pwidth00.wav",
    "protoss/witness/pwidth01.wav",
    "protoss/witness/pwipss00.wav",
    "protoss/witness/pwipss01.wav",
    "protoss/witness/pwipss02.wav",
    "protoss/witness/pwipss03.wav",
    "protoss/witness/pwipss04.wav",
    "protoss/witness/pwiwht00.wav",
    "protoss/witness/pwiwht01.wav",
    "protoss/witness/pwiyes00.wav",
    "protoss/witness/pwiyes01.wav",
    "protoss/zealot/pzeatt00.wav",
    "protoss/zealot/pzeatt01.wav",
    "protoss/zealot/pzehit00.wav",
    "protoss/zealot/pzerag00.wav",
    "protoss/zealot/pzerdy00.wav",
    "protoss/zealot/pzepss00.wav",
    "protoss/zealot/pzepss01.wav",
    "protoss/zealot/pzepss02.wav",
    "protoss/zealot/pzewht00.wav",
    "protoss/zealot/pzewht01.wav",
    "protoss/zealot/pzewht02.wav",
    "protoss/zealot/pzewht03.wav",
    "protoss/zealot/pzeyes00.wav",
    "protoss/zealot/pzeyes01.wav",
    "protoss/zealot/pzeyes02.wav",
    "protoss/zealot/pzeyes03.wav",
    "protoss/zealot/pzedth00.wav",
    "protoss/fenixd/ufdpss00.wav",
    "protoss/fenixd/ufdpss01.wav",
    "protoss/fenixd/ufdpss02.wav",
    "protoss/fenixd/ufdpss03.wav",
    "protoss/fenixd/ufdwht00.wav",
    "protoss/fenixd/ufdwht01.wav",
    "protoss/fenixd/ufdwht02.wav",
    "protoss/fenixd/ufdwht03.wav",
    "protoss/fenixd/ufdyes00.wav",
    "protoss/fenixd/ufdyes01.wav",
    "protoss/fenixd/ufdyes02.wav",
    "protoss/fenixd/ufdyes03.wav",
    "protoss/fenixz/ufepss00.wav",
    "protoss/fenixz/ufepss01.wav",
    "protoss/fenixz/ufepss02.wav",
    "protoss/fenixz/ufepss03.wav",
    "protoss/fenixz/ufewht00.wav",
    "protoss/fenixz/ufewht01.wav",
    "protoss/fenixz/ufewht02.wav",
    "protoss/fenixz/ufewht03.wav",
    "protoss/fenixz/ufeyes00.wav",
    "protoss/fenixz/ufeyes01.wav",
    "protoss/fenixz/ufeyes02.wav",
    "protoss/fenixz/ufeyes03.wav",
    "protoss/gantrithor/utcpss00.wav",
    "protoss/gantrithor/utcpss01.wav",
    "protoss/gantrithor/utcpss02.wav",
    "protoss/gantrithor/utcpss03.wav",
    "protoss/gantrithor/utcwht00.wav",
    "protoss/gantrithor/utcwht01.wav",
    "protoss/gantrithor/utcwht02.wav",
    "protoss/gantrithor/utcwht03.wav",
    "protoss/gantrithor/utcyes00.wav",
    "protoss/gantrithor/utcyes01.wav",
    "protoss/gantrithor/utcyes02.wav",
    "protoss/gantrithor/utcyes03.wav",
    "protoss/tassadar/utapss00.wav",
    "protoss/tassadar/utapss01.wav",
    "protoss/tassadar/utapss02.wav",
    "protoss/tassadar/utapss03.wav",
    "protoss/tassadar/utawht00.wav",
    "protoss/tassadar/utawht01.wav",
    "protoss/tassadar/utawht02.wav",
    "protoss/tassadar/utawht03.wav",
    "protoss/tassadar/utayes00.wav",
    "protoss/tassadar/utayes01.wav",
    "protoss/tassadar/utayes02.wav",
    "protoss/tassadar/utayes03.wav",
    "protoss/tassadar/utadth00.wav",
    "protoss/darktemplar/pdtrdy00.wav",
    "protoss/darktemplar/pdtpss00.wav",
    "protoss/darktemplar/pdtpss01.wav",
    "protoss/darktemplar/pdtpss02.wav",
    "protoss/darktemplar/pdtpss03.wav",
    "protoss/darktemplar/pdtwht00.wav",
    "protoss/darktemplar/pdtwht01.wav",
    "protoss/darktemplar/pdtwht02.wav",
    "protoss/darktemplar/pdtwht03.wav",
    "protoss/darktemplar/pdtyes00.wav",
    "protoss/darktemplar/pdtyes01.wav",
    "protoss/darktemplar/pdtyes02.wav",
    "protoss/darktemplar/pdtyes03.wav",
    "protoss/darktemplar/pdtdth00.wav",
    "protoss/zeratul/uzepss00.wav",
    "protoss/zeratul/uzepss01.wav",
    "protoss/zeratul/uzepss02.wav",
    "protoss/zeratul/uzepss03.wav",
    "protoss/zeratul/uzewht00.wav",
    "protoss/zeratul/uzewht01.wav",
    "protoss/zeratul/uzewht02.wav",
    "protoss/zeratul/uzewht03.wav",
    "protoss/zeratul/uzeyes00.wav",
    "protoss/zeratul/uzeyes01.wav",
    "protoss/zeratul/uzeyes02.wav",
    "protoss/zeratul/uzeyes03.wav",
    "protoss/zeratul/uzedth00.wav",
    "zerg/bldg/zchwht00.wav",
    "zerg/bldg/zcbwht00.wav",
    "zerg/bldg/zevwht00.wav",
    "zerg/bldg/zfcwht00.wav",
    "zerg/bldg/zhawht00.wav",
    "zerg/bldg/zhiwht00.wav",
    "zerg/bldg/zigwht00.wav",
    "zerg/bldg/zlrwht00.wav",
    "zerg/bldg/zluwht00.wav",
    "zerg/bldg/zmcwht00.wav",
    "protoss/bldg/pnawht00.wav (2)",
    "zerg/bldg/zmhwht00.wav",
    "zerg/bldg/znewht00.wav",
    "zerg/bldg/znywht00.wav",
    "zerg/bldg/zo1wht00.wav",
    "zerg/bldg/zrcwht00.wav",
    "zerg/bldg/zsbwht00.wav",
    "zerg/bldg/zscwht00.wav",
    "zerg/bldg/zspwht00.wav",
    "zerg/bldg/zbldgdth.wav",
    "zerg/avenger/zavrdy00.wav",
    "zerg/avenger/zavdth00.wav",
    "zerg/avenger/zavatt00.wav",
    "zerg/avenger/zavhit00.wav",
    "zerg/avenger/zavpss00.wav",
    "zerg/avenger/zavpss01.wav",
    "zerg/avenger/zavwht00.wav",
    "zerg/avenger/zavwht01.wav",
    "zerg/avenger/zavyes00.wav",
    "zerg/avenger/zavyes01.wav",
    "zerg/broodling/zbrdth00.wav",
    "zerg/broodling/zbratt00.wav",
    "zerg/broodling/zbrrdy00.wav",
    "zerg/broodling/zbrpss00.wav",
    "zerg/broodling/zbrpss01.wav",
    "zerg/broodling/zbrpss02.wav",
    "zerg/broodling/zbrpss03.wav",
    "zerg/broodling/zbrwht00.wav",
    "zerg/broodling/zbrwht01.wav",
    "zerg/broodling/zbrwht02.wav",
    "zerg/broodling/zbrwht03.wav",
    "zerg/broodling/zbryes00.wav",
    "zerg/broodling/zbryes01.wav",
    "zerg/broodling/zbryes02.wav",
    "zerg/bugguy/zbgrdy00.wav",
    "zerg/bugguy/zbgrdy00.wav (2)",
    "zerg/bugguy/zbgpss00.wav",
    "zerg/bugguy/zbgpss01.wav",
    "zerg/bugguy/zbgpss02.wav",
    "zerg/bugguy/zbgpss03.wav",
    "zerg/bugguy/zbgwht00.wav",
    "zerg/bugguy/zbgwht01.wav",
    "zerg/bugguy/zbgwht02.wav",
    "zerg/bugguy/zbgwht03.wav",
    "zerg/bugguy/zbgyes00.wav",
    "zerg/bugguy/zbgyes01.wav",
    "zerg/bugguy/zbgyes02.wav",
    "zerg/bugguy/zbgyes03.wav",
    "zerg/defiler/zdecon00.wav",
    "zerg/defiler/zderdy00.wav",
    "zerg/defiler/zdedth00.wav",
    "zerg/defiler/zdeblo00.wav",
    "zerg/defiler/zdeblo01.wav",
    "zerg/defiler/zdepss00.wav",
    "zerg/defiler/zdepss01.wav",
    "zerg/defiler/zdepss02.wav",
    "zerg/defiler/zdewht00.wav",
    "zerg/defiler/zdewht01.wav",
    "zerg/defiler/zdewht02.wav",
    "zerg/defiler/zdeyes00.wav",
    "zerg/defiler/zdeyes01.wav",
    "zerg/defiler/zdeyes02.wav",
    "zerg/egg/zegrdy00.wav",
    "zerg/egg/zegwht00.wav",
    "zerg/egg/zegwht01.wav",
    "zerg/egg/zegdth00.wav",
    "zerg/egg/zegpss00.wav",
    "zerg/drone/zdrrdy00.wav",
    "zerg/drone/zdrdth00.wav",
    "zerg/drone/zdrpss00.wav",
    "zerg/drone/zdrpss01.wav",
    "zerg/drone/zdrpss02.wav",
    "zerg/drone/zdrwht00.wav",
    "zerg/drone/zdrwht01.wav",
    "zerg/drone/zdrwht02.wav",
    "zerg/drone/zdrwht03.wav",
    "zerg/drone/zdrwht04.wav",
    "zerg/drone/zdryes00.wav",
    "zerg/drone/zdryes01.wav",
    "zerg/drone/zdryes02.wav",
    "zerg/drone/zdryes03.wav",
    "zerg/drone/zdryes04.wav",
    "zerg/drone/zdrmin00.wav",
    "zerg/larva/zladth00.wav",
    "terran/advisor/taderr04.wav (5)",
    "zerg/larva/zlapss00.wav",
    "zerg/larva/zlawht00.wav",
    "zerg/guardian/zgudth00.wav",
    "zerg/guardian/zgupss00.wav",
    "zerg/guardian/zgupss01.wav",
    "zerg/guardian/zgupss02.wav",
    "zerg/guardian/zgupss03.wav",
    "zerg/guardian/zgurdy00.wav",
    "zerg/guardian/zguwht00.wav",
    "zerg/guardian/zguwht01.wav",
    "zerg/guardian/zguwht02.wav",
    "zerg/guardian/zguwht03.wav",
    "zerg/guardian/zguyes00.wav",
    "zerg/guardian/zguyes01.wav",
    "zerg/guardian/zguyes02.wav",
    "zerg/guardian/zguyes03.wav",
    "zerg/hydra/zhyrdy00.wav",
    "zerg/hydra/zhydth00.wav",
    "zerg/hydra/zhypss00.wav",
    "zerg/hydra/zhypss01.wav",
    "zerg/hydra/zhywht00.wav",
    "zerg/hydra/zhywht01.wav",
    "zerg/hydra/zhywht02.wav",
    "zerg/hydra/zhyyes00.wav",
    "zerg/hydra/zhyyes01.wav",
    "zerg/hydra/zhyyes02.wav",
    "zerg/hydra/zhyyes03.wav",
    "zerg/ultra/zulror00.wav",
    "zerg/ultra/zuldth00.wav",
    "zerg/ultra/zulpss00.wav",
    "zerg/ultra/zulpss01.wav",
    "zerg/ultra/zulpss02.wav",
    "zerg/ultra/zulrdy00.wav",
    "zerg/ultra/zulwht00.wav",
    "zerg/ultra/zulwht01.wav",
    "zerg/ultra/zulwht02.wav",
    "zerg/ultra/zulwht03.wav",
    "zerg/ultra/zulyes00.wav",
    "zerg/ultra/zulyes01.wav",
    "zerg/ultra/zulyes02.wav",
    "zerg/ultra/zulyes03.wav",
    "zerg/ultra/zulatt00.wav",
    "zerg/ultra/zulatt01.wav",
    "zerg/ultra/zulatt02.wav",
    "zerg/ultra/zulhit00.wav",
    "zerg/ultra/zulhit01.wav",
    "zerg/zergling/zzedth00.wav",
    "zerg/zergling/zzepss00.wav",
    "zerg/zergling/zzepss01.wav",
    "zerg/zergling/zzepss02.wav",
    "zerg/zergling/zzerdy00.wav",
    "zerg/zergling/zzewht00.wav",
    "zerg/zergling/zzewht01.wav",
    "zerg/zergling/zzewht02.wav",
    "zerg/zergling/zzewht03.wav",
    "zerg/zergling/zzeyes00.wav",
    "zerg/zergling/zzeyes01.wav",
    "zerg/zergling/zzeyes02.wav",
    "zerg/zergling/zzeyes03.wav",
    "zerg/overlord/zovrdy00.wav",
    "zerg/overlord/zovdth00.wav",
    "zerg/overlord/zovpss00.wav",
    "zerg/overlord/zovwht00.wav",
    "zerg/overlord/zovwht01.wav",
    "zerg/overlord/zovwht02.wav",
    "zerg/overlord/zovwht03.wav",
    "zerg/overlord/zovyes00.wav",
    "zerg/overlord/zovyes01.wav",
    "zerg/overlord/zovyes02.wav",
    "zerg/overlord/zovyes03.wav",
    "zerg/queen/zqutag00.wav",
    "zerg/queen/zqutag01.wav",
    "zerg/queen/zquswm00.wav",
    "zerg/queen/zquswm01.wav",
    "zerg/queen/zquens00.wav",
    "zerg/queen/zqudth00.wav",
    "zerg/queen/zqudth01.wav",
    "zerg/queen/zqudth02.wav",
    "zerg/queen/zqurdy00.wav",
    "zerg/queen/zqupss00.wav",
    "zerg/queen/zqupss01.wav",
    "zerg/queen/zqupss02.wav",
    "zerg/queen/zqupss03.wav",
    "zerg/queen/zquwht00.wav",
    "zerg/queen/zquwht01.wav",
    "zerg/queen/zquwht02.wav",
    "zerg/queen/zquwht03.wav",
    "zerg/queen/zquyes00.wav",
    "zerg/queen/zquyes01.wav",
    "zerg/queen/zquyes02.wav",
    "zerg/queen/zquyes03.wav",
    "zerg/mutalid/zmurdy00.wav",
    "zerg/mutalid/zmudth00.wav",
    "zerg/mutalid/zmupss00.wav",
    "zerg/mutalid/zmupss01.wav",
    "zerg/mutalid/zmupss02.wav",
    "zerg/mutalid/zmupss03.wav",
    "zerg/mutalid/zmuwht00.wav",
    "zerg/mutalid/zmuwht01.wav",
    "zerg/mutalid/zmuwht02.wav",
    "zerg/mutalid/zmuwht03.wav",
    "zerg/mutalid/zmuyes00.wav",
    "zerg/mutalid/zmuyes01.wav",
    "zerg/mutalid/zmuyes02.wav",
    "zerg/mutalid/zmuyes03.wav",
    "zerg/zergkerri/ukipss00.wav",
    "zerg/zergkerri/ukipss01.wav",
    "zerg/zergkerri/ukipss02.wav",
    "zerg/zergkerri/ukipss03.wav",
    "zerg/zergkerri/ukiwht00.wav",
    "zerg/zergkerri/ukiwht01.wav",
    "zerg/zergkerri/ukiwht02.wav",
    "zerg/zergkerri/ukiwht03.wav",
    "zerg/zergkerri/ukiyes00.wav",
    "zerg/zergkerri/ukiyes01.wav",
    "zerg/zergkerri/ukiyes02.wav",
    "zerg/zergkerri/ukiyes03.wav",
    "zerg/zergkerri/ukidth00.wav",
    "misc/critters/pbwht01.wav",
    "misc/critters/pbwht02.wav",
    "misc/critters/pbwht03.wav",
    "misc/critters/pbdeath01.wav",
    "misc/critters/scwht01.wav",
    "misc/critters/scwht02.wav",
    "misc/critters/scwht03.wav",
    "misc/critters/scdeath01.wav",
    "misc/critters/terwht01.wav",
    "misc/critters/terwht02.wav",
    "misc/critters/terwht03.wav",
    "misc/critters/terdeath01.wav",
    "terran/duran/tdnpss00.wav",
    "terran/duran/tdnpss01.wav",
    "terran/duran/tdnpss02.wav",
    "terran/duran/tdnpss03.wav",
    "terran/duran/tdnpss04.wav",
    "terran/duran/tdnpss05.wav",
    "terran/duran/tdnpss06.wav",
    "terran/duran/tdnpss07.wav",
    "terran/duran/tdnpss08.wav",
    "terran/duran/tdnwht00.wav",
    "terran/duran/tdnwht01.wav",
    "terran/duran/tdnwht02.wav",
    "terran/duran/tdnwht03.wav",
    "terran/duran/tdnyes00.wav",
    "terran/duran/tdnyes01.wav",
    "terran/duran/tdnyes02.wav",
    "terran/duran/tdnyes03.wav",
    "terran/duran/tdndth00.wav",
    "terran/medic/tmedcure.wav",
    "terran/medic/tmdrdy00.wav",
    "terran/medic/tmddth00.wav",
    "terran/medic/tmdwht00.wav",
    "terran/medic/tmdwht01.wav",
    "terran/medic/tmdwht02.wav",
    "terran/medic/tmdwht03.wav",
    "terran/medic/tmdyes00.wav",
    "terran/medic/tmdyes01.wav",
    "terran/medic/tmdyes02.wav",
    "terran/medic/tmdyes03.wav",
    "terran/medic/tmdpss00.wav",
    "terran/medic/tmdpss01.wav",
    "terran/medic/tmdpss02.wav",
    "terran/medic/tmdpss03.wav",
    "terran/medic/tmdpss04.wav",
    "terran/medic/tmdpss05.wav",
    "terran/medic/tmdpss06.wav",
    "terran/medic/tmedflsh.wav",
    "terran/medic/tmedrest.wav",
    "terran/medic/tmedheal.wav",
    "terran/medic/miopia1.wav",
    "terran/frigate/afteron.wav",
    "terran/frigate/afteroff.wav",
    "bullet/tfrhit.wav",
    "bullet/tfrshoot.wav",
    "terran/frigate/tvkrdy00.wav",
    "terran/frigate/tvkpss00.wav",
    "terran/frigate/tvkpss01.wav",
    "terran/frigate/tvkpss02.wav",
    "terran/frigate/tvkpss03.wav",
    "terran/frigate/tvkpss04.wav",
    "terran/frigate/tvkpss05.wav",
    "terran/frigate/tvkwht00.wav",
    "terran/frigate/tvkwht01.wav",
    "terran/frigate/tvkwht02.wav",
    "terran/frigate/tvkwht03.wav",
    "terran/frigate/tvkyes00.wav",
    "terran/frigate/tvkyes01.wav",
    "terran/frigate/tvkyes02.wav",
    "terran/frigate/tvkyes03.wav",
    "terran/frigate/tvkyes04.wav",
    "terran/frigate/tvkdth00.wav",
    "protoss/corsair/pcordy00.wav",
    "protoss/corsair/pcorhit1.wav",
    "protoss/corsair/pcorhit2.wav",
    "protoss/corsair/pcowht00.wav",
    "protoss/corsair/pcowht01.wav",
    "protoss/corsair/pcowht02.wav",
    "protoss/corsair/pcowht03.wav",
    "protoss/corsair/pcoyes00.wav",
    "protoss/corsair/pcoyes01.wav",
    "protoss/corsair/pcoyes02.wav",
    "protoss/corsair/pcoyes03.wav",
    "protoss/corsair/pcopss00.wav",
    "protoss/corsair/pcopss01.wav",
    "protoss/corsair/pcopss02.wav",
    "protoss/corsair/pcopss03.wav",
    "protoss/corsair/pcopss04.wav",
    "protoss/corsair/pcopss05.wav",
    "protoss/corsair/pcopss06.wav",
    "protoss/corsair/pcorweb1.wav",
    "protoss/corsair/pcorlasr2.wav",
    "protoss/darchon/feedback.wav",
    "protoss/darchon/mind.wav",
    "protoss/darchon/paraattk.wav",
    "protoss/darchon/parahit.wav",
    "protoss/darchon/pdardy00.wav",
    "protoss/darchon/pdrdth00.wav",
    "protoss/darchon/pdapss00.wav",
    "protoss/darchon/pdapss01.wav",
    "protoss/darchon/pdapss02.wav",
    "protoss/darchon/pdapss03.wav",
    "protoss/darchon/pdawht00.wav",
    "protoss/darchon/pdawht01.wav",
    "protoss/darchon/pdawht02.wav",
    "protoss/darchon/pdawht03.wav",
    "protoss/darchon/pdayes00.wav",
    "protoss/darchon/pdayes01.wav",
    "protoss/darchon/pdayes02.wav",
    "protoss/darchon/pdayes03.wav",
    "zerg/lurker/zlurdy00.wav",
    "zerg/lurker/zludth00.wav",
    "zerg/lurker/zlupss00.wav",
    "zerg/lurker/zlupss01.wav",
    "zerg/lurker/zlupss02.wav",
    "zerg/lurker/zlupss03.wav",
    "zerg/lurker/zluwht00.wav",
    "zerg/lurker/zluwht01.wav",
    "zerg/lurker/zluwht02.wav",
    "zerg/lurker/zluwht03.wav",
    "zerg/lurker/zluyes00.wav",
    "zerg/lurker/zluyes01.wav",
    "zerg/lurker/zluyes02.wav",
    "zerg/lurker/zluyes03.wav",
    "zerg/lurker/zluburrw.wav",
    "zerg/devourer/firesuck.wav",
    "zerg/devourer/goophit.wav",
    "zerg/devourer/zdvrdy00.wav",
    "zerg/devourer/zdvdth00.wav",
    "zerg/devourer/zdvpss00.wav",
    "zerg/devourer/zdvpss01.wav",
    "zerg/devourer/zdvpss02.wav",
    "zerg/devourer/zdvwht00.wav",
    "zerg/devourer/zdvwht01.wav",
    "zerg/devourer/zdvwht02.wav",
    "zerg/devourer/zdvyes00.wav",
    "zerg/devourer/zdvyes01.wav",
    "zerg/devourer/zdvyes02.wav",
    "zerg/devourer/zdvyes03.wav",
    "bullet/zlrkfir1.wav",
    "bullet/zlrkfir2.wav",
    "bullet/zlrkhit1.wav",
    "bullet/zlrkhit2.wav",
    "zerg/zergduran/zdnpss00.wav",
    "zerg/zergduran/zdnpss01.wav",
    "zerg/zergduran/zdnpss02.wav",
    "zerg/zergduran/zdnpss03.wav",
    "zerg/zergduran/zdnpss04.wav",
    "zerg/zergduran/zdnpss05.wav",
    "zerg/zergduran/zdnpss06.wav",
    "zerg/zergduran/zdnpss07.wav",
    "zerg/zergduran/zdnpss08.wav",
    "zerg/zergduran/zdnwht00.wav",
    "zerg/zergduran/zdnwht01.wav",
    "zerg/zergduran/zdnwht02.wav",
    "zerg/zergduran/zdnwht03.wav",
    "zerg/zergduran/zdnyes00.wav",
    "zerg/zergduran/zdnyes01.wav",
    "zerg/zergduran/zdnyes02.wav",
    "zerg/zergduran/zdnyes03.wav",
    "zerg/zergduran/zdndth00.wav",
    "protoss/artanis/patpss00.wav",
    "protoss/artanis/patpss01.wav",
    "protoss/artanis/patpss02.wav",
    "protoss/artanis/patpss03.wav",
    "protoss/artanis/patpss04.wav",
    "protoss/artanis/patpss05.wav",
    "protoss/artanis/patwht00.wav",
    "protoss/artanis/patwht01.wav",
    "protoss/artanis/patwht02.wav",
    "protoss/artanis/patwht03.wav",
    "protoss/artanis/patyes00.wav",
    "protoss/artanis/patyes01.wav",
    "protoss/artanis/patyes02.wav",
    "protoss/artanis/patyes03.wav",
]



from random import randint

from helper import *


@TestInstance
def test_array():
    k = EUDArray(9)
    n = EUDVariable(k)
    b = EUDVariable()
    b << n
    a = EUDArray.cast(b)
    for i in range(9):
        a.set(i, 2**i)

    expect = [2**i for i in range(9)]
    test_equality("array ev.set(i, 2**i)", [a[i] for i in range(9)], expect)

    # constant array test
    EP_SetRValueStrictMode(False)
    QueueGameCommand_Select(1, EUDArray([0x59CCA8]))

    for i in range(9):
        if i < 5:
            k[i] += 1 + i
        else:
            k[i] += EUDVariable(1 + i)
        expect[i] += 1 + i
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array cn[i] += 1+i", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            k[i] -= 2 ** (10 - i)
        else:
            k[i] -= EUDVariable(2 ** (10 - i))
        expect[i] -= 2 ** (10 - i)
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array cn[i] -= 2**(10-i)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            k[i] *= 3 * (i + 1)
        else:
            k[i] *= EUDVariable(3 * (i + 1))
        expect[i] *= 3 * (i + 1)
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array cn[i] *= 3*(i+1)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            k[i] //= 7 * (i + 1)
        else:
            k[i] //= EUDVariable(7 * (i + 1))
        expect[i] //= 7 * (i + 1)
    test_equality("array cn[i] //= 7*(i+1)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            k[i] %= 9 ** (i + 1)
        else:
            k[i] %= EUDVariable(9 ** (i + 1))
        expect[i] %= 9 ** (i + 1)
    test_equality("array cn[i] %= 9**(i+1)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            k[i] <<= i + 1
        else:
            k[i] <<= EUDVariable(i + 1)
        expect[i] <<= i + 1
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array cn[i] <<= i+1", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            k[i] >>= 16 - i
        else:
            k[i] >>= EUDVariable(16 - i)
        expect[i] >>= 16 - i
    test_equality("array cn[i] >>= 16-i", [a[i] for i in range(9)], expect)

    """
    for i in range(9):
        if i < 5:
            k[i] **= 2 + i
        else:
            k[i] **= EUDVariable(2 + i)
        expect[i] **= 2 + i
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array cn[i] **= 2+i", [a[i] for i in range(9)], expect)
    """

    mask = randint(0, 0xFFFFFFFF)
    for i in range(9):
        if i < 5:
            k[i] &= mask
        else:
            k[i] &= EUDVariable(mask)
        expect[i] &= mask
    test_equality(f"array cn[i] &= 0x{mask:X}", [a[i] for i in range(9)], expect)

    mask = randint(0, 0xFFFFFFFF)
    for i in range(9):
        if i < 5:
            k[i] |= mask
        else:
            k[i] |= EUDVariable(mask)
        expect[i] |= mask
    test_equality(f"array cn[i] |= 0x{mask:X}", [a[i] for i in range(9)], expect)

    mask = randint(0, 0xFFFFFFFF)
    for i in range(9):
        if i < 5:
            k[i] ^= mask
        else:
            k[i] ^= EUDVariable(mask)
        expect[i] ^= mask
    test_equality(f"array cn[i] ^= 0x{mask:X}", [a[i] for i in range(9)], expect)

    # casted array test

    for i in range(9):
        if i < 5:
            a[i] += 1 + i
        else:
            a[i] += EUDVariable(1 + i)
        expect[i] += 1 + i
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[i] += 1+i", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            a[i] -= 2 ** (10 - i)
        else:
            a[i] -= EUDVariable(2 ** (10 - i))
        expect[i] -= 2 ** (10 - i)
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[i] -= 2**(10-i)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            a[i] *= 3 * (i + 1)
        else:
            a[i] *= EUDVariable(3 * (i + 1))
        expect[i] *= 3 * (i + 1)
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[i] *= 3*(i+1)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            a[i] //= 7 * (i + 1)
        else:
            a[i] //= EUDVariable(7 * (i + 1))
        expect[i] //= 7 * (i + 1)
    test_equality("array ev[i] //= 7*(i+1)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            a[i] %= 9 ** (i + 1)
        else:
            a[i] %= EUDVariable(9 ** (i + 1))
        expect[i] %= 9 ** (i + 1)
    test_equality("array ev[i] %= 9**(i+1)", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            a[i] <<= i + 1
        else:
            a[i] <<= EUDVariable(i + 1)
        expect[i] <<= i + 1
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[i] <<= i+1", [a[i] for i in range(9)], expect)

    for i in range(9):
        if i < 5:
            a[i] >>= 16 - i
        else:
            a[i] >>= EUDVariable(16 - i)
        expect[i] >>= 16 - i
    test_equality("array ev[i] >>= 16-i", [a[i] for i in range(9)], expect)

    """
    for i in range(9):
        if i < 5:
            a[i] **= 2 + i
        else:
            a[i] **= EUDVariable(2 + i)
        expect[i] **= 2 + i
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[i] **= 2+i", [a[i] for i in range(9)], expect)
    """

    mask = randint(0, 0xFFFFFFFF)
    for i in range(9):
        if i < 5:
            a[i] &= mask
        else:
            a[i] &= EUDVariable(mask)
        expect[i] &= mask
    test_equality(f"array ev[i] &= 0x{mask:X}", [a[i] for i in range(9)], expect)

    mask = randint(0, 0xFFFFFFFF)
    for i in range(9):
        if i < 5:
            a[i] |= mask
        else:
            a[i] |= EUDVariable(mask)
        expect[i] |= mask
    test_equality(f"array ev[i] |= 0x{mask:X}", [a[i] for i in range(9)], expect)

    mask = randint(0, 0xFFFFFFFF)
    for i in range(9):
        if i < 5:
            a[i] ^= mask
        else:
            a[i] ^= EUDVariable(mask)
        expect[i] ^= mask
    test_equality(f"array ev[i] ^= 0x{mask:X}", [a[i] for i in range(9)], expect)

    # casted array with variable index test

    for i in EUDLoopRange(9):
        a[i] += 1 + i
    for i in range(9):
        expect[i] += 1 + i
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[ev] += 1+i", [a[i] for i in range(9)], expect)

    x = EUDVariable(2**2)
    index = EUDVariable(9)
    if EUDWhile()(index >= 1):
        index -= 1
        a[index] -= x
        x += x
    EUDEndWhile()
    for i in range(9):
        expect[i] -= 2 ** (10 - i)
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[ev] -= 2**(10-i)", [a[i] for i in range(9)], expect)

    for i in EUDLoopRange(9):
        a[i] *= 3 * (i + 1)
    for i in range(9):
        expect[i] *= 3 * (i + 1)
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[ev] *= 3*(i+1)", [a[i] for i in range(9)], expect)

    for i in EUDLoopRange(9):
        a[i] //= 7 * (i + 1)
    for i in range(9):
        expect[i] //= 7 * (i + 1)
    test_equality("array ev[ev] //= 7*(i+1)", [a[i] for i in range(9)], expect)

    x << 9**1
    for i in EUDLoopRange(9):
        a[i] %= x
        x *= 9
    for i in range(9):
        expect[i] %= 9 ** (i + 1)
    test_equality("array ev[ev] %= 9**(i+1)", [a[i] for i in range(9)], expect)

    for i in EUDLoopRange(9):
        a[i] <<= i + 1
    for i in range(9):
        expect[i] <<= i + 1
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[ev] <<= i+1", [a[i] for i in range(9)], expect)

    for i in EUDLoopRange(9):
        a[i] >>= 16 - i
    for i in range(9):
        expect[i] >>= 16 - i
    test_equality("array ev[ev] >>= 16-i", [a[i] for i in range(9)], expect)

    """
    for i in EUDLoopRange(9):
        a[i] **= 2 + i
    for i in range(9):
        expect[i] **= 2 + i
        expect[i] = expect[i] & 0xFFFFFFFF
    test_equality("array ev[ev] **= 2+i", [a[i] for i in range(9)], expect)
    """

    mask = randint(0, 0xFFFFFFFF)
    for i in EUDLoopRange(9):
        a[i] &= mask
    for i in range(9):
        expect[i] &= mask
    test_equality(f"array ev[ev] &= 0x{mask:X}", [a[i] for i in range(9)], expect)

    mask = randint(0, 0xFFFFFFFF)
    for i in EUDLoopRange(9):
        a[i] |= mask
    for i in range(9):
        expect[i] |= mask
    test_equality(f"array ev[ev] |= 0x{mask:X}", [a[i] for i in range(9)], expect)

    mask = randint(0, 0xFFFFFFFF)
    for i in EUDLoopRange(9):
        a[i] ^= mask
    for i in range(9):
        expect[i] ^= mask
    test_equality(f"array ev[ev] ^= 0x{mask:X}", [a[i] for i in range(9)], expect)

    EP_SetRValueStrictMode(True)



# Copyright 2014 by trgk.
# All rights reserved.
# This file is part of EUD python library (eudplib),
# and is released under "MIT License Agreement". Please see the LICENSE
# file that should have been included as part of this package.

from ... import utils as ut
from ...localize import _
from .. import rawtrigger as bt
from .. import variable as ev
from .eudfuncn import EUDFuncN


def _apply_types(typesdecl, varlist):
    """
    EUD-Typecast each variable to declared types.

    :param typesdecl: List of types. Can be set to None if you don't want
        to typecast anything. Each item of the list can also be None which is
        equivalent to EUDVariable here.
    :param varlist: List of variables.

    :returns: List of casted variables.
    """
    if typesdecl is None:
        return varlist

    rets = []
    # FIXME: armoha/euddraft#34
    if len(varlist) == len(typesdecl) + 1:
        rets.append(varlist[0])
        varlist = varlist[1:]
    ut.ep_assert(
        len(varlist) == len(typesdecl),
        _("Different number of variables({}) from type declarations({})").format(
            len(varlist), len(typesdecl)
        )
        + f"argtypes: {typesdecl}, args: {varlist}",
    )

    for vartype, var in zip(typesdecl, varlist):
        if vartype == ev.EUDVariable or vartype is None:
            rets.append(var)
        else:
            rets.append(vartype.cast(var))

    return rets


class EUDTypedFuncN(EUDFuncN):

    """
    EUDFuncN specialization for EUDTypedFunc. This will pre-convert
    arguments to types prior to function call.
    """

    def __init__(self, argn, callerfunc, bodyfunc, argtypes, rettypes, *, traced):
        super().__init__(argn, callerfunc, bodyfunc, traced=traced)
        self._argtypes = argtypes
        self._rettypes = rettypes

    def __call__(self, *args, ret=None):
        # This layer is necessary for function to accept non-EUDVariable object
        # as argument. For instance, EUDFuncN.
        args = _apply_types(self._argtypes, args)
        rets = super().__call__(*args, ret=ret)

        # Cast returns to rettypes before caller code.
        rets = ut.Assignable2List(rets)
        rets = _apply_types(self._rettypes, rets)
        return ut.List2Assignable(rets)


class EUDXTypedFuncN(EUDTypedFuncN):

    """
    EUDFuncN specialization for EUDX.
    """

    def __init__(
        self, argn, callerfunc, bodyfunc, argtypes, rettypes, argmasks, *, traced
    ):
        super().__init__(
            argn, callerfunc, bodyfunc, argtypes, rettypes, traced=traced
        )
        self._argmasks = argmasks

    def _create_func_args(self):
        ut.ep_assert(
            self._argn == len(self._argmasks),
            _("Different number of arguments({}) from mask declarations({})."),
        )
        if self._fargs is None:
            self._fargs = [ev.EUDXVariable(0, mask) for mask in self._argmasks]


class EUDFullFuncN(EUDFuncN):
    def __init__(
        self, argn, arginitvals, callerfunc, bodyfunc, argtypes, rettypes, *, traced
    ):
        arginitvals = list(arginitvals)
        while len(arginitvals) < argn:
            arginitvals.append((0, bt.SetTo, 0, None))
        super().__init__(arginitvals, callerfunc, bodyfunc, traced=traced)
        self._argtypes = argtypes
        self._rettypes = rettypes

    def __call__(self, *args, ret=None):
        # This layer is necessary for function to accept non-EUDVariable object
        # as argument. For instance, EUDFuncN.
        args = _apply_types(self._argtypes, args)
        rets = super().__call__(*args, ret=ret)

        # Cast returns to rettypes before caller code.
        rets = ut.Assignable2List(rets)
        rets = _apply_types(self._rettypes, rets)
        return ut.List2Assignable(rets)
